@@ -1,21 +1,8 @@
-# MediaInfo
-# Copyright (C) 2002-2012 MediaArea.net SARL, Info@MediaArea.net
-#
-# This program is free software: you can redistribute it and/or modify it
-# under the terms of the GNU Lesser General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public License
-# along with this program. If not, see <http:#www.gnu.org/licenses/>.
-#
-#+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-#+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+##  Copyright (c) MediaArea.net SARL. All Rights Reserved.
+ #
+ #  Use of this source code is governed by a BSD-style license that can
+ #  be found in the License.html file in the root of the source tree.
+ ##
 
 #! /bin/sh
 
@@ -57,6 +44,9 @@ cp ../Project/GNU/Library/libmediainfo-config.in MediaInfo_Lib_GNU_FromSource/Pr
 # Copying : Source
 mkdir -p MediaInfo_Lib_GNU_FromSource/Source/ThirdParty/base64
 cp -r ../Source/ThirdParty/base64/*.h MediaInfo_Lib_GNU_FromSource/Source/ThirdParty/base64/
+mkdir -p MediaInfo_Lib_GNU_FromSource/Source/ThirdParty/md5
+cp -r ../Source/ThirdParty/md5/*.h MediaInfo_Lib_GNU_FromSource/Source/ThirdParty/md5/
+cp -r ../Source/ThirdParty/md5/*.c MediaInfo_Lib_GNU_FromSource/Source/ThirdParty/md5/
 mkdir -p MediaInfo_Lib_GNU_FromSource/Source/ThirdParty/tinyxml2
 cp -r ../Source/ThirdParty/tinyxml2/*.h MediaInfo_Lib_GNU_FromSource/Source/ThirdParty/tinyxml2/
 cp -r ../Source/ThirdParty/tinyxml2/*.cpp MediaInfo_Lib_GNU_FromSource/Source/ThirdParty/tinyxml2/
