@@ -1,20 +1,9 @@
-// HowToUse - Example for MediaInfoLib (commandline version)
-// Copyright (C) 2004-2008 Jerome Martinez, Zen@MediaArea.net
-//
-// This library is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Library General Public License as published by
-// the Free Software Foundation, either version 2 of the License, or
-// any later version.
-//
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public License
-// along with this program. If not, see <http://www.gnu.org/licenses/>.
-//
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+/*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
+ *
+ *  Use of this source code is governed by a BSD-style license that can
+ *  be found in the License.html file in the root of the source tree.
+ */
+
 //+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 //
 // Example for MediaInfoLib
@@ -41,7 +30,7 @@ using namespace MediaInfoNameSpace;
     #endif //_UNICODE
 #endif //__MINGW32
 
-int main (int argc, Char *argv[])
+int main (int /*argc*/, Char * /*argv[]*/)
 {
     //Information about MediaInfo
     MediaInfo MI;
