@@ -1,21 +1,8 @@
-// File_Dts - Info for DTS files
-// Copyright (C) 2004-2012 MediaArea.net SARL, Info@MediaArea.net
-//
-// This library is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Library General Public License as published by
-// the Free Software Foundation, either version 2 of the License, or
-// any later version.
-//
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public License
-// along with this library. If not, see <http://www.gnu.org/licenses/>.
-//
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+/*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
+ *
+ *  Use of this source code is governed by a BSD-style license that can
+ *  be found in the License.html file in the root of the source tree.
+ */
 
 //---------------------------------------------------------------------------
 // Pre-compilation
@@ -40,7 +27,9 @@
 #if MEDIAINFO_EVENTS
     #include "MediaInfo/MediaInfo_Events.h"
 #endif //MEDIAINFO_EVENTS
+#include <algorithm>
 using namespace ZenLib;
+using namespace std;
 //---------------------------------------------------------------------------
 
 namespace MediaInfoLib
@@ -93,11 +82,11 @@ const char*  DTS_ChannelPositions[16]=
     "Front: L R",
     "Front: L R",
     "Front: L C R",
-    "Front: L R, Side: C",
-    "Front: L C R, Side: C",
+    "Front: L R, Back: C",
+    "Front: L C R, Back: C",
     "Front: L R, Side: L R",
     "Front: L C R, Side: L R",
-    "Front: L R, Side: L R, Back: L R",
+    "Front: L C C R, Side: L R",
     "Front: L C R, Side: L R",
     "Front: L R, Side: L R, Back: L R",
     "Front: L C R, Side: L R, Back: L R",
@@ -118,7 +107,7 @@ const char*  DTS_ChannelPositions2[16]=
     "3/1/0",
     "2/2/0",
     "3/2/0",
-    "2/2/2",
+    "4/2/0",
     "3/2/0",
     "2/2/2",
     "3/2/2",
@@ -126,6 +115,27 @@ const char*  DTS_ChannelPositions2[16]=
     "3/2/3",
 };
 
+//---------------------------------------------------------------------------
+const char*  DTS_ChannelLayout[16]=
+{
+    "C",
+    "1+1",
+    "L R",
+    "L R",
+    "Lt Rt",
+    "C L R",
+    "L R Cs",
+    "C L R Cs",
+    "L R Ls Rs",
+    "C L R Ls Rs",
+    "Cl Cr L R Ls Rs",
+    "C L R Ls Rs",
+    "C L R Ls Rs Rls Rrs",
+    "C L R Ls Rs Rls Rrs",
+    "L R Ls Rs Rls Cs Cs Rrs",
+    "C L R Ls Rs Rls Cs Rrs",
+};
+
 //---------------------------------------------------------------------------
 const char* DTS_ExtensionAudioDescriptor[]=
 {
@@ -193,7 +203,7 @@ std::string DTS_HD_SpeakerActivityMask (int16u SpeakerActivityMask)
     if (SpeakerActivityMask&0x2000)
         Text+=", HiSide: L R";
 
-    if ((SpeakerActivityMask&0xC000)==0x0C00)
+    if ((SpeakerActivityMask&0xC000)==0x0C000)
         Text+=", HiRear: L C R";
     else
     {
@@ -261,7 +271,7 @@ std::string DTS_HD_SpeakerActivityMask2 (int16u SpeakerActivityMask)
     if (SpeakerActivityMask&0x2000)
         Text+=".2";
 
-    if ((SpeakerActivityMask&0xC000)==0x0C00)
+    if ((SpeakerActivityMask&0xC000)==0x0C000)
         Text+=".3";
     else
     {
@@ -346,10 +356,12 @@ File_Dts::File_Dts()
     //In
     Frame_Count_Valid=MediaInfoLib::Config.ParseSpeed_Get()>=0.3?32:2;
 
+    //Buffer
+    Save_Buffer=NULL;
+
     //Temp
-    Parser=NULL;
     HD_size=0;
-    Primary_Frame_Byte_Size_minus_1=0;
+    Primary_Frame_Byte_Size=0;
     HD_SpeakerActivityMask=(int16u)-1;
     channel_arrangement=(int8u)-1;
     channel_arrangement_XCh=(int8u)-1;
@@ -368,13 +380,6 @@ File_Dts::File_Dts()
     Core_Exists=false;
 }
 
-//---------------------------------------------------------------------------
-File_Dts::~File_Dts()
-{
-    //Pointers
-    delete Parser;
-}
-
 //***************************************************************************
 // Streams management
 //***************************************************************************
@@ -387,9 +392,6 @@ void File_Dts::Streams_Fill()
     Stream_Prepare(Stream_Audio);
     Fill(Stream_Audio, 0, Audio_Format, "DTS");
 
-    if (Parser) //LE or 14-bit
-        return; //filled by the parser
-
     if (!Profile.empty())
         Fill(Stream_Audio, 0, Audio_Format_Profile, Profile+(Core_Exists?__T(" / Core"):__T("")));
     else if (ES)
@@ -430,10 +432,11 @@ void File_Dts::Streams_Fill()
             Fill(Stream_Audio, 0, Audio_SamplingRate, DTS_SamplingRate[sample_frequency_X96k]);
         if(HD_TotalNumberChannels!=(int8u)-1)
             Fill(Stream_Audio, 0, Audio_Channel_s_, HD_TotalNumberChannels);
-        if (bit_rate<29 || Profile==__T("Express"))
-            Fill(Stream_Audio, 0, Audio_BitRate, BitRate_Get(true), 0);
         if (Profile==__T("Express"))
+        {
+            Fill(Stream_Audio, 0, Audio_BitRate, BitRate_Get(true), 0);
             Fill(Stream_Audio, 0, Audio_BitRate_Mode, "CBR");
+        }
     }
 
     //Core data
@@ -452,18 +455,23 @@ void File_Dts::Streams_Fill()
             BitRate=__T("Variable");
         else if (bit_rate==31)
             BitRate=__T("LossLess");
+        if (Profile==__T("HRA"))
+            Fill(Stream_Audio, 0, Audio_BitRate, BitRate_Get(true), 0);
+        if ( Profile==__T("MA"))
+            Fill(Stream_Audio, 0, Audio_BitRate, "Unknown");
         if (BitRate!=Retrieve(Stream_Audio, 0, Audio_BitRate))
             Fill(Stream_Audio, 0, Audio_BitRate, BitRate);
         if (Profile.find(__T("MA"))==0 || bit_rate==31)
             Fill(Stream_Audio, 0, Audio_Compression_Mode, "Lossless / Lossy", Unlimited, true, true);
 
         int8u Channels;
-        Ztring ChannelPositions, ChannelPositions2;
+        Ztring ChannelPositions, ChannelPositions2, ChannelLayout;
         if (channel_arrangement<16)
         {
             Channels=DTS_Channels[channel_arrangement]+(lfe_effects?1:0);
             ChannelPositions.From_Local(DTS_ChannelPositions[channel_arrangement]);
             ChannelPositions2.From_Local(DTS_ChannelPositions2[channel_arrangement]);
+            ChannelLayout.From_Local(DTS_ChannelLayout[channel_arrangement]);
         }
         else
         {
@@ -474,6 +482,7 @@ void File_Dts::Streams_Fill()
         {
             ChannelPositions+=__T(", LFE");
             ChannelPositions2+=__T(".1");
+            ChannelLayout+=__T(" LFE");
         }
         if (Channels!=Retrieve(Stream_Audio, 0, Audio_Channel_s_).To_int8u())
             Fill(Stream_Audio, 0, Audio_Channel_s_, Channels);
@@ -481,6 +490,8 @@ void File_Dts::Streams_Fill()
             Fill(Stream_Audio, 0, Audio_ChannelPositions, ChannelPositions);
         if (ChannelPositions2!=Retrieve(Stream_Audio, 0, Audio_ChannelPositions_String2))
             Fill(Stream_Audio, 0, Audio_ChannelPositions_String2, ChannelPositions2);
+        if (ChannelLayout!=Retrieve(Stream_Audio, 0, Audio_ChannelLayout))
+            Fill(Stream_Audio, 0, Audio_ChannelLayout, ChannelLayout);
         if (DTS_Resolution[bits_per_sample]!=Retrieve(Stream_Audio, 0, Audio_BitDepth).To_int8u())
             Fill(Stream_Audio, 0, Audio_BitDepth, DTS_Resolution[bits_per_sample]);
     }
@@ -489,19 +500,13 @@ void File_Dts::Streams_Fill()
 //---------------------------------------------------------------------------
 void File_Dts::Streams_Finish()
 {
-    if (Parser) //LE or 14-bit
-    {
-        Parser->Finish();
-        Merge(*Parser, Stream_Audio, 0, 0);
-        Fill(Stream_Audio, 0, Audio_MuxingMode, BigEndian?"BE":"LE");
-        Fill(Stream_Audio, 0, Audio_MuxingMode, Word?"16":"14");
-        return;
-    }
+    Fill(Stream_Audio, 0, Audio_Format_Settings_Endianness, BigEndian?"Big":"Little", Unlimited, true, true);
+    Fill(Stream_Audio, 0, Audio_Format_Settings_Mode, Word?"16":"14", Unlimited, true, true);
 
     if (FrameInfo.PTS!=(int64u)-1 && FrameInfo.PTS>PTS_Begin)
     {
-        Fill(Stream_Audio, 0, Audio_Duration, float64_int64s(((float64)(FrameInfo.PTS-PTS_Begin))/1000000));
-        Fill(Stream_Audio, 0, Audio_FrameCount, float64_int64s(((float64)(FrameInfo.PTS-PTS_Begin))/1000000/32));
+        Fill(Stream_Audio, 0, Audio_Duration, ((float64)(FrameInfo.PTS-PTS_Begin))/1000000, 0, true);
+        Fill(Stream_Audio, 0, Audio_FrameCount, ((float64)(FrameInfo.PTS-PTS_Begin))/1000000/32, 0, true);
     }
 }
 
@@ -540,12 +545,9 @@ bool File_Dts::Synchronize()
     //Synchronizing
     while (Buffer_Offset+6<=Buffer_Size)
     {
-        int64u Value=CC6(Buffer+Buffer_Offset);
-        if ((Value&0xFFFFFFFFFC00LL)==0x7FFE8001FC00LL  //16 bits and big    endian Core
-         || (Value&0xFFFFFFFF00FCLL)==0xFE7F018000FCLL  //16 bits and little endian Core
-         || (Value&0xFFFFFFFFF7F0LL)==0x1FFFE80007F0LL  //14 bits and big    endian Core
-         || (Value&0xFFFFFFFFF0F7LL)==0xFF1F00E8F007LL  //14 bits and little endian Core
-         || (Value&0xFFFFFFFF0000LL)==0x645820250000LL) //16 bits and big    endian HD
+        if (!FrameSynchPoint_Test())
+            return false; //Need more data
+        if (Synched)
             break;
         Buffer_Offset++;
     }
@@ -606,15 +608,6 @@ bool File_Dts::Synchronize()
         return false;
     }
 
-    //Configuration - 14 bits or Little Endian
-    switch (CC1(Buffer+Buffer_Offset))
-    {
-        default   : Word=true;  BigEndian=true;  break; //16 bits and big    endian bitstream
-        case 0xFE : Word=true;  BigEndian=false; break; //16 bits and little endian bitstream
-        case 0x1F : Word=false; BigEndian=true;  break; //14 bits and big    endian bitstream
-        case 0xFF : Word=false; BigEndian=false; break; //14 bits and little endian bitstream
-    }
-
     //Synched
     return true;
 }
@@ -622,27 +615,30 @@ bool File_Dts::Synchronize()
 //---------------------------------------------------------------------------
 bool File_Dts::Synched_Test()
 {
+    //Padding
+    while (Buffer_Offset<Buffer_Size && Buffer[Buffer_Offset]==0x00)
+        Buffer_Offset++;
+
     //Must have enough buffer for having header
-    if (Buffer_Offset+4>Buffer_Size)
+    if (Buffer_Offset+6>Buffer_Size)
         return false;
 
     //Quick test of synchro
-    int32u Value=CC4(Buffer+Buffer_Offset);
-    switch (Value)
-    {
-        case 0x7FFE8001 :  //16 bits and big    endian Core
-        case 0xFE7F0180 :  //16 bits and little endian Core
-        case 0x1FFFE800 :  //14 bits and big    endian Core
-        case 0xFF1F00E8 :  //14 bits and little endian Core
-        case 0x64582025 :  //16 bits and big    endian HD
-                            break;
-        default         :   Synched=false;
-    }
+    if (!FrameSynchPoint_Test())
+        return false; //Need more data
+    if (!Synched)
+        return true;
 
     //We continue
     return true;
 }
 
+//---------------------------------------------------------------------------
+void File_Dts::Read_Buffer_Unsynched()
+{
+    FrameInfo=frame_info();
+}
+
 //***************************************************************************
 // Buffer - Demux
 //***************************************************************************
@@ -667,82 +663,6 @@ bool File_Dts::Demux_UnpacketizeContainer_Test()
 }
 #endif //MEDIAINFO_DEMUX
 
-//***************************************************************************
-// Buffer - Global
-//***************************************************************************
-
-//---------------------------------------------------------------------------
-void File_Dts::Read_Buffer_Continue()
-{
-    //Exception handling
-    int8u* Dest=NULL;
-    try
-    {
-
-    //Mapping to an understable bitstream if needed
-    if (MustSynchronize && !Synchro_Manage())
-        return; //Wait for more data
-    if (Synched && (!Word || !BigEndian))
-    {
-        //Preparing new buffer
-        size_t Dest_Size=Word?Buffer_Size:(Buffer_Size*14/16);
-        Dest=new int8u[Dest_Size];
-        if (Word)
-        {
-            for (size_t Pos=0; Pos+1<Buffer_Size; Pos+=2)
-            {
-                Dest[Pos+1]=Buffer[Pos  ];
-                Dest[Pos  ]=Buffer[Pos+1];
-            }
-        }
-        else
-        {
-            for (size_t Pos=0; Pos+7<Buffer_Size; Pos+=8)
-            {
-                int64u Value;
-                if (BigEndian)
-                    Value =(((int64u)(   BigEndian2int16u(Buffer+Pos  )&0x3FFF))<<42)
-                         | (((int64u)(   BigEndian2int16u(Buffer+Pos+2)&0x3FFF))<<28)
-                         | (((int64u)(   BigEndian2int16u(Buffer+Pos+4)&0x3FFF))<<14)
-                         | (((int64u)(   BigEndian2int16u(Buffer+Pos+6)&0x3FFF))    );
-                else
-                    Value =(((int64u)(LittleEndian2int16u(Buffer+Pos  )&0x3FFF))<<42)
-                         | (((int64u)(LittleEndian2int16u(Buffer+Pos+2)&0x3FFF))<<28)
-                         | (((int64u)(LittleEndian2int16u(Buffer+Pos+4)&0x3FFF))<<14)
-                         | (((int64u)(LittleEndian2int16u(Buffer+Pos+6)&0x3FFF))    );
-                int56u2BigEndian(Dest+Pos/8*7, Value);
-            }
-        }
-
-        //Parsing
-        if (Parser==NULL)
-        {
-            Parser=new File_Dts;
-            ((File_Dts*)Parser)->Frame_Count_Valid=Frame_Count_Valid;
-            Open_Buffer_Init(Parser);
-        }
-        Demux(Dest, Dest_Size, ContentType_MainStream);
-        Open_Buffer_Continue(Parser, Dest, Dest_Size);
-        if (!Status[IsFilled] && Parser->Status[IsFilled])
-        {
-            Accept("DTS");
-            Fill("DTS");
-        }
-        if (!Status[IsFinished] && Parser->Status[IsFinished])
-            Finish("DTS");
-
-        delete[] Dest;
-        Buffer_Offset+=Buffer_Size;
-    }
-
-    //Exception handling
-    }
-    catch(...)
-    {
-        delete[] Dest;
-    }
-}
-
 //***************************************************************************
 // Buffer - Per element
 //***************************************************************************
@@ -750,12 +670,35 @@ void File_Dts::Read_Buffer_Continue()
 //---------------------------------------------------------------------------
 void File_Dts::Header_Parse()
 {
+    Header_Fill_Size(Original_Size);
+}
+
+//***************************************************************************
+// Elements
+//***************************************************************************
+
+//---------------------------------------------------------------------------
+void File_Dts::Data_Parse()
+{
+    if (Save_Buffer)
+    {
+        File_Offset+=Buffer_Offset;
+        swap(Buffer, Save_Buffer);
+        swap(Buffer_Offset, Save_Buffer_Offset);
+        swap(Buffer_Size, Save_Buffer_Size);
+        if (!Word)
+            Element_Size=Element_Size*14/16;
+    }
+
     //Parsing
     int32u Sync;
     Get_B4 (Sync,                                               "Sync");
     if (Sync==0x64582025)
     {
         //HD
+        Element_Name("HD");
+        Element_Code=1;
+
         int16u header_size;
         int8u  SubStreamIndex, NumAssets, NumAudioPresent;
         bool isBlownUpHeader, StaticFieldsPresent;
@@ -876,24 +819,26 @@ void File_Dts::Header_Parse()
         }
         BS_End();
         Skip_XX(header_size-Element_Offset,                   "Unknown");
-
-        //Filling
-        Header_Fill_Size(HD_size);
-        Header_Fill_Code(1, "HD");
     }
     else
     {
         //Frame
+        Element_Name("Frame");
+        Element_Code=0;
+
         int8u  EncoderSoftwareRevision;
         bool   crc_present;
         BS_Begin();
         Info_SB(    FrameType,                                      "Frame Type"); Param_Info1(DTS_FrameType[FrameType]);
         Skip_S1( 5,                                                 "Deficit Sample Count");
         Get_SB (    crc_present,                                    "CRC Present");
-        Skip_S1( 7,                                                 "Number of PCM Sample Blocks");
-        Get_S2 (14, Primary_Frame_Byte_Size_minus_1,                "Primary Frame Byte Size minus 1");
-        Primary_Frame_Byte_Size_minus_1+=1;
-        if (!Word) Primary_Frame_Byte_Size_minus_1=Primary_Frame_Byte_Size_minus_1*8/14*2; Param_Info2(Primary_Frame_Byte_Size_minus_1, " bytes"); //Word is on 14 bits!
+        Get_S2 ( 7, Number_Of_PCM_Sample_Blocks,                    "Number of PCM Sample Blocks");
+        Number_Of_PCM_Sample_Blocks++;
+        Get_S2 (14, Primary_Frame_Byte_Size,                        "Primary Frame Byte Size minus 1");
+        Primary_Frame_Byte_Size++;
+        if (!Word)
+            Primary_Frame_Byte_Size=Primary_Frame_Byte_Size*16/14; //Word is on 14 bits
+        Param_Info2(Primary_Frame_Byte_Size, " bytes");
         Get_S1 ( 6, channel_arrangement,                            "Audio Channel Arrangement"); Param_Info2(DTS_Channels[channel_arrangement], " channels");
         Get_S1 ( 4, sample_frequency,                               "Core Audio Sampling Frequency"); Param_Info2(DTS_SamplingRate[sample_frequency], " Hz");
         Get_S1 ( 5, bit_rate,                                       "Transmission Bit Rate"); Param_Info2(DTS_BitRate[bit_rate], " bps");
@@ -930,27 +875,6 @@ void File_Dts::Header_Parse()
                     break;
         }
         BS_End();
-
-        //Filling
-        Header_Fill_Size(Primary_Frame_Byte_Size_minus_1);
-        Header_Fill_Code(0);
-    }
-}
-
-//***************************************************************************
-// Elements
-//***************************************************************************
-
-//---------------------------------------------------------------------------
-void File_Dts::Data_Parse()
-{
-    //Partial frame
-    if ((Element_Code==0 && Header_Size+Element_Size<Primary_Frame_Byte_Size_minus_1)
-     || (Element_Code==1 && Header_Size+Element_Size<HD_size))
-    {
-        Element_Name("Partial frame");
-        Skip_XX(Element_Size,                                   "Data");
-        return;
     }
 
     //Name
@@ -982,7 +906,19 @@ void File_Dts::Data_Parse()
     //If filled
     if (Status[IsFilled])
     {
-        Skip_XX(Element_Size,                                   "Data");
+        //Little Endian and 14-bit streams management
+        if (Save_Buffer)
+        {
+            delete[] Buffer;
+            Buffer=Save_Buffer; Save_Buffer=NULL;
+            Buffer_Offset=Save_Buffer_Offset;
+            Buffer_Size=Save_Buffer_Size;
+            File_Offset-=Buffer_Offset;
+            if (!Word)
+                Element_Size=Element_Size*16/14;
+        }
+
+        Skip_XX(Element_Size-Element_Offset,                    "Data");
         return;
     }
 
@@ -993,6 +929,18 @@ void File_Dts::Data_Parse()
         case 1  : HD(); break;
         default : Skip_XX(Element_Size,                         "Data");
     }
+
+    //Little Endian and 14-bit streams management
+    if (Save_Buffer)
+    {
+        delete[] Buffer;
+        Buffer=Save_Buffer; Save_Buffer=NULL;
+        Buffer_Offset=Save_Buffer_Offset;
+        Buffer_Size=Save_Buffer_Size;
+        File_Offset-=Buffer_Offset;
+        if (!Word)
+            Element_Size=Element_Size*16/14;
+    }
 }
 
 //***************************************************************************
@@ -1039,7 +987,7 @@ void File_Dts::Core()
     }
 
     //Parsing
-    Skip_XX(Core_Size,                                          "Core data");
+    Skip_XX(Core_Size-Element_Offset,                           "Core data");
     if (ExtendedCoding && (ExtensionAudioDescriptor==2 || ExtensionAudioDescriptor==3))
     {
         Element_Begin0();
@@ -1284,8 +1232,10 @@ float64 File_Dts::BitRate_Get(bool WithHD)
         float64 BitRate;
         if (Profile==__T("Express"))
             BitRate=0; //No core bitrate
+        else if (DTS_SamplingRate[sample_frequency])
+            BitRate=((float64)Primary_Frame_Byte_Size)*8/(Number_Of_PCM_Sample_Blocks*32)*DTS_SamplingRate[sample_frequency]; //(float64)DTS_BitRate[bit_rate];
         else
-            BitRate=(float64)DTS_BitRate[bit_rate];
+            BitRate=0; //Problem
         if (WithHD && HD_ExSSFrameDurationCode!=(int8u)-1)
         {
             int32u SamplePerFrames=HD_ExSSFrameDurationCode;
@@ -1316,16 +1266,140 @@ float64 File_Dts::BitRate_Get(bool WithHD)
                 default     :   SamplePerFrames=    0; break; //Can never happen (4 bits)
             }
             if (SamplePerFrames)
-                BitRate+=HD_size*8*DTS_HD_MaximumSampleRate[HD_MaximumSampleRate]/SamplePerFrames;
+                BitRate+=((float64)HD_size)*8*DTS_HD_MaximumSampleRate[HD_MaximumSampleRate]/SamplePerFrames;
         }
-        //if (Primary_Frame_Byte_Size_minus_1 && Profile==__T("HRA"))
-        //    BitRate*=1+((float64)HD_size)/Primary_Frame_Byte_Size_minus_1; //HD block are not in the nominal bitrate
+        //if (Primary_Frame_Byte_Size && Profile==__T("HRA"))
+        //    BitRate*=1+((float64)HD_size)/Primary_Frame_Byte_Size; //HD block are not in the nominal bitrate
         return BitRate;
     }
     else
         return 0;
 }
 
+//---------------------------------------------------------------------------
+bool File_Dts::FrameSynchPoint_Test()
+{
+    if (Save_Buffer)
+        return true; //Test already made by Synchronize()
+
+    int64u Value=CC6(Buffer+Buffer_Offset);
+    if ((Value&0xFFFFFFFFFC00LL)==0x7FFE8001FC00LL  //16 bits and big    endian Core
+     || (Value&0xFFFFFFFF00FCLL)==0xFE7F018000FCLL  //16 bits and little endian Core
+     || (Value&0xFFFFFFFFF7F0LL)==0x1FFFE80007F0LL  //14 bits and big    endian Core
+     || (Value&0xFFFFFFFFF0F7LL)==0xFF1F00E8F007LL  //14 bits and little endian Core
+     || (Value&0xFFFFFFFF0000LL)==0x645820250000LL) //16 bits and big    endian HD
+    {
+        //Configuration - 14 bits or Little Endian
+        switch (Buffer[Buffer_Offset])
+        {
+            default   : Word=true;  BigEndian=true;  break; //16 bits and big    endian bitstream
+            case 0xFE : Word=true;  BigEndian=false; break; //16 bits and little endian bitstream
+            case 0x1F : Word=false; BigEndian=true;  break; //14 bits and big    endian bitstream
+            case 0xFF : Word=false; BigEndian=false; break; //14 bits and little endian bitstream
+        }
+
+        int32u Size;
+        if (Buffer[Buffer_Offset]==0x64) //HD
+        {
+            if (Buffer_Offset+10>Buffer_Size)
+                return false; //Need more data
+
+            bool isBlownUpHeader=(Buffer[Buffer_Offset+5]&0x20)?true:false;
+            if (isBlownUpHeader)
+                Size=((Buffer[Buffer_Offset+6]&0x01)<<19)
+                   | ( Buffer[Buffer_Offset+7]      <<11)
+                   | ( Buffer[Buffer_Offset+8]      << 3)
+                   | ( Buffer[Buffer_Offset+9]      >> 5);
+            else
+                Size=((Buffer[Buffer_Offset+6]&0x1F)<<13)
+                   | ( Buffer[Buffer_Offset+7]      << 3)
+                   | ( Buffer[Buffer_Offset+8]      >> 5);
+            Size++;
+            Original_Size=Size;
+        }
+        else
+        {
+            if (Word)
+            {
+                if (BigEndian)
+                    Size=((Buffer[Buffer_Offset+5]&0x03)<<12)
+                       | ( Buffer[Buffer_Offset+6]      << 4)
+                       | ( Buffer[Buffer_Offset+7]      >> 4);
+                else
+                    Size=((Buffer[Buffer_Offset+4]&0x03)<<12)
+                       | ( Buffer[Buffer_Offset+7]      << 4)
+                       | ( Buffer[Buffer_Offset+6]      >> 4);
+                Size++;
+                Original_Size=Size;
+            }
+            else
+            {
+                if (BigEndian)
+                    Size=((Buffer[Buffer_Offset+6]&0x03)<<12)
+                       | ( Buffer[Buffer_Offset+7]      << 4)
+                       | ((Buffer[Buffer_Offset+8]&0x3C)>> 2);
+                else
+                    Size=((Buffer[Buffer_Offset+7]&0x03)<<12)
+                       | ( Buffer[Buffer_Offset+6]      << 4)
+                       | ((Buffer[Buffer_Offset+9]&0x3C)>> 2);
+                Size++;
+                Original_Size=Size*16/14;
+            }
+        }
+        if (Buffer_Offset+Size>Buffer_Size)
+            return false; //Need more data
+
+        if (!Word || !BigEndian)
+        {
+            Save_Buffer=Buffer;
+            Save_Buffer_Offset=Buffer_Offset;
+            Save_Buffer_Size=Buffer_Size;
+
+            //Preparing new buffer
+            if (Word)
+            {
+                int8u* Buffer_Little=new int8u[Size];
+                for (size_t Pos=0; Pos+1<Size; Pos+=2)
+                {
+                    Buffer_Little[Pos+1]=Save_Buffer[Buffer_Offset+Pos  ];
+                    Buffer_Little[Pos  ]=Save_Buffer[Buffer_Offset+Pos+1];
+                }
+                Save_Buffer=Buffer_Little;
+                Save_Buffer_Offset=0;
+                Save_Buffer_Size=Size;
+            }
+            else
+            {
+                int8u* Dest=new int8u[Size];
+                for (size_t Pos=0; Pos+8<=Original_Size; Pos+=8)
+                {
+                    int64u Value;
+                    if (BigEndian)
+                        Value =(((int64u)(   BigEndian2int16u(Buffer+Pos  )&0x3FFF))<<42)
+                             | (((int64u)(   BigEndian2int16u(Buffer+Pos+2)&0x3FFF))<<28)
+                             | (((int64u)(   BigEndian2int16u(Buffer+Pos+4)&0x3FFF))<<14)
+                             | (((int64u)(   BigEndian2int16u(Buffer+Pos+6)&0x3FFF))    );
+                    else
+                        Value =(((int64u)(LittleEndian2int16u(Buffer+Pos  )&0x3FFF))<<42)
+                             | (((int64u)(LittleEndian2int16u(Buffer+Pos+2)&0x3FFF))<<28)
+                             | (((int64u)(LittleEndian2int16u(Buffer+Pos+4)&0x3FFF))<<14)
+                             | (((int64u)(LittleEndian2int16u(Buffer+Pos+6)&0x3FFF))    );
+                    int56u2BigEndian(Dest+Pos*14/16, Value);
+                }
+                Save_Buffer=Dest;
+                Save_Buffer_Offset=0;
+                Save_Buffer_Size=Size;
+            }
+        }
+
+        Synched=true;
+    }
+    else
+        Synched=false;
+
+    return true;
+}
+
 //---------------------------------------------------------------------------
 } //NameSpace
 
