@@ -1,20 +1,9 @@
-// File_Pcm - Info for PCM files
-// Copyright (C) 2007-2012 MediaArea.net SARL, Info@MediaArea.net
-//
-// This library is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Library General Public License as published by
-// the Free Software Foundation, either version 2 of the License, or
-// any later version.
-//
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public License
-// along with this library. If not, see <http://www.gnu.org/licenses/>.
-//
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+/*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
+ *
+ *  Use of this source code is governed by a BSD-style license that can
+ *  be found in the License.html file in the root of the source tree.
+ */
+
 //+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 //
 // Information about PCM files
@@ -41,10 +30,19 @@ class File_Pcm : public File__Analyze
 {
 public :
     //In
+    int64u          Frame_Count_Valid;
     ZenLib::Ztring  Codec;
-    int16u          BitDepth;
-    int16u          Channels;
-    bool            IsRawPcm;
+    int32u          SamplingRate;
+    int8u           BitDepth;
+    int8u           Channels;
+    int8u           Endianness;
+    int8u           Sign;
+
+    //Buffer - Global
+    #if MEDIAINFO_DEMUX
+    void Read_Buffer_Continue ();
+    int64u  Frame_Count_Valid_Demux;
+    #endif //MEDIAINFO_DEMUX
 
     //Constructor/Destructor
     File_Pcm();
@@ -52,17 +50,14 @@ public :
 private :
     //Streams management
     void Streams_Fill();
+    void Streams_Finish();
 
-    //Buffer - Global
-    void Read_Buffer_Continue ();
+    //Buffer - File header
+    bool FileHeader_Begin();
 
     //Buffer - Per element
     void Header_Parse();
     void Data_Parse();
-
-    //Elements
-    void VOB();
-    void M2TS();
 };
 
 } //NameSpace
