@@ -1,21 +1,8 @@
-// File__Analyze - Base for analyze files
-// Copyright (C) 2007-2012 MediaArea.net SARL, Info@MediaArea.net
-//
-// This library is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Library General Public License as published by
-// the Free Software Foundation, either version 2 of the License, or
-// any later version.
-//
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public License
-// along with this library. If not, see <http://www.gnu.org/licenses/>.
-//
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+/*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
+ *
+ *  Use of this source code is governed by a BSD-style license that can
+ *  be found in the License.html file in the root of the source tree.
+ */
 
 //---------------------------------------------------------------------------
 // Pre-compilation
@@ -99,26 +86,30 @@ extern MediaInfo_Config Config;
 //---------------------------------------------------------------------------
 void File__Analyze::BS_Begin()
 {
-    if (Element_Offset>Element_Size)
-        Element_Offset=Element_Size;
     size_t BS_Size;
-    if (Buffer_Offset+Element_Size<=Buffer_Size)
+    if (Element_Offset>=Element_Size)
+        BS_Size=0;
+    else if (Buffer_Offset+Element_Size<=Buffer_Size)
         BS_Size=(size_t)(Element_Size-Element_Offset);
+    else if (Buffer_Offset+Element_Offset<=Buffer_Size)
+        BS_Size=Buffer_Size-(size_t)(Buffer_Offset+Element_Offset);
     else
-        BS_Size=Buffer_Size-(Buffer_Offset+(size_t)Element_Offset);
+        BS_Size=0;
+
     BS->Attach(Buffer+Buffer_Offset+(size_t)Element_Offset, BS_Size);
 }
 
 //---------------------------------------------------------------------------
 void File__Analyze::BS_Begin_LE()
 {
-    if (Element_Offset>Element_Size)
-        Element_Offset=Element_Size;
     size_t BS_Size;
     if (Buffer_Offset+Element_Size<=Buffer_Size)
         BS_Size=(size_t)(Element_Size-Element_Offset);
+    else if (Buffer_Offset+Element_Offset<=Buffer_Size)
+        BS_Size=Buffer_Size-(size_t)(Buffer_Offset+Element_Offset);
     else
-        BS_Size=Buffer_Size-(Buffer_Offset+(size_t)Element_Offset);
+        BS_Size=0;
+
     BT->Attach(Buffer+Buffer_Offset+(size_t)Element_Offset, BS_Size);
 }
 
@@ -269,7 +260,7 @@ void File__Analyze::Get_BF10(float80 &Info, const char* Name)
 }
 
 //---------------------------------------------------------------------------
-void File__Analyze::Get_BFP4(size_t Bits, float32 &Info, const char* Name)
+void File__Analyze::Get_BFP4(int8u Bits, float32 &Info, const char* Name)
 {
     INTEGRITY_SIZE_ATLEAST_INT(4);
     BS_Begin();
@@ -446,7 +437,7 @@ void File__Analyze::Skip_BF4(const char* Name)
 }
 
 //---------------------------------------------------------------------------
-void File__Analyze::Skip_BFP4(size_t Bits, const char* Name)
+void File__Analyze::Skip_BFP4(int8u Bits, const char* Name)
 {
     INTEGRITY_SIZE_ATLEAST(4);
     BS_Begin();
@@ -1020,7 +1011,7 @@ void File__Analyze::Get_EB(int64u &Info, const char* Name)
         Element_Offset++;
         return;
     }
-    int32u Size=0;
+    int8u Size=0;
     int32u Size_Mark=0;
     BS_Begin();
     while (Size_Mark==0 && BS->Remain() && Size<=8)
@@ -1112,7 +1103,7 @@ void File__Analyze::Get_ES(int64s &Info, const char* Name)
 {
     //Element size
     INTEGRITY_SIZE_ATLEAST_INT(1);
-    int32u Size=0;
+    int8u Size=0;
     int32u Size_Mark=0;
     BS_Begin();
     while (Size_Mark==0 && BS->Remain() && Size<=8)
@@ -1812,10 +1803,9 @@ void File__Analyze::Skip_PA(const char* Name)
 {
     INTEGRITY_SIZE_ATLEAST(1);
     int8u Size=Buffer[Buffer_Offset+(size_t)Element_Offset];
-    int8u Pad=(Size%2)?0:1;
-    INTEGRITY_SIZE_ATLEAST(1+Size+Pad);
+    INTEGRITY_SIZE_ATLEAST(1+Size);
     if (Trace_Activated && Size) Param(Name, Ztring().From_Local((const char*)(Buffer+Buffer_Offset+(size_t)Element_Offset+1), (size_t)Size));
-    Element_Offset+=1+Size+Pad;
+    Element_Offset+=1+Size;
 }
 
 //***************************************************************************
@@ -1881,7 +1871,7 @@ void File__Analyze::Skip_Flags(int64u ValueToPut, const char* Name)
 //***************************************************************************
 
 //---------------------------------------------------------------------------
-void File__Analyze::Get_BS(size_t Bits, int32u &Info, const char* Name)
+void File__Analyze::Get_BS(int8u Bits, int32u &Info, const char* Name)
 {
     INTEGRITY_INT(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
     Info=BS->Get4(Bits);
@@ -1897,7 +1887,7 @@ void File__Analyze::Get_SB(             bool &Info, const char* Name)
 }
 
 //---------------------------------------------------------------------------
-void File__Analyze::Get_S1(size_t Bits, int8u &Info, const char* Name)
+void File__Analyze::Get_S1(int8u Bits, int8u &Info, const char* Name)
 {
     INTEGRITY_INT(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
     Info=BS->Get1(Bits);
@@ -1909,7 +1899,7 @@ void File__Analyze::Get_S1(size_t Bits, int8u &Info, const char* Name)
 }
 
 //---------------------------------------------------------------------------
-void File__Analyze::Get_S2(size_t Bits, int16u &Info, const char* Name)
+void File__Analyze::Get_S2(int8u Bits, int16u &Info, const char* Name)
 {
     INTEGRITY_INT(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
     Info=BS->Get2(Bits);
@@ -1917,7 +1907,7 @@ void File__Analyze::Get_S2(size_t Bits, int16u &Info, const char* Name)
 }
 
 //---------------------------------------------------------------------------
-void File__Analyze::Get_S3(size_t Bits, int32u &Info, const char* Name)
+void File__Analyze::Get_S3(int8u Bits, int32u &Info, const char* Name)
 {
     INTEGRITY_INT(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
     Info=BS->Get4(Bits);
@@ -1925,7 +1915,7 @@ void File__Analyze::Get_S3(size_t Bits, int32u &Info, const char* Name)
 }
 
 //---------------------------------------------------------------------------
-void File__Analyze::Get_S4(size_t Bits, int32u &Info, const char* Name)
+void File__Analyze::Get_S4(int8u Bits, int32u &Info, const char* Name)
 {
     INTEGRITY_INT(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
     Info=BS->Get4(Bits);
@@ -1933,7 +1923,7 @@ void File__Analyze::Get_S4(size_t Bits, int32u &Info, const char* Name)
 }
 
 //---------------------------------------------------------------------------
-void File__Analyze::Get_S5(size_t Bits, int64u &Info, const char* Name)
+void File__Analyze::Get_S5(int8u Bits, int64u &Info, const char* Name)
 {
     INTEGRITY_INT(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
     Info=BS->Get8(Bits);
@@ -1941,7 +1931,7 @@ void File__Analyze::Get_S5(size_t Bits, int64u &Info, const char* Name)
 }
 
 //---------------------------------------------------------------------------
-void File__Analyze::Get_S6(size_t Bits, int64u &Info, const char* Name)
+void File__Analyze::Get_S6(int8u Bits, int64u &Info, const char* Name)
 {
     INTEGRITY_INT(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
     Info=BS->Get8(Bits);
@@ -1949,7 +1939,7 @@ void File__Analyze::Get_S6(size_t Bits, int64u &Info, const char* Name)
 }
 
 //---------------------------------------------------------------------------
-void File__Analyze::Get_S7(size_t Bits, int64u &Info, const char* Name)
+void File__Analyze::Get_S7(int8u Bits, int64u &Info, const char* Name)
 {
     INTEGRITY_INT(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
     Info=BS->Get8(Bits);
@@ -1957,7 +1947,7 @@ void File__Analyze::Get_S7(size_t Bits, int64u &Info, const char* Name)
 }
 
 //---------------------------------------------------------------------------
-void File__Analyze::Get_S8(size_t Bits, int64u &Info, const char* Name)
+void File__Analyze::Get_S8(int8u Bits, int64u &Info, const char* Name)
 {
     INTEGRITY_INT(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
     Info=BS->Get8(Bits);
@@ -1965,7 +1955,7 @@ void File__Analyze::Get_S8(size_t Bits, int64u &Info, const char* Name)
 }
 
 //---------------------------------------------------------------------------
-void File__Analyze::Peek_BS(size_t Bits, int32u &Info)
+void File__Analyze::Peek_BS(int8u Bits, int32u &Info)
 {
     INTEGRITY_INT(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
     Info=BS->Peek4(Bits);
@@ -1979,56 +1969,56 @@ void File__Analyze::Peek_SB(              bool &Info)
 }
 
 //---------------------------------------------------------------------------
-void File__Analyze::Peek_S1(size_t Bits, int8u &Info)
+void File__Analyze::Peek_S1(int8u Bits, int8u &Info)
 {
     INTEGRITY_INT(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
     Info=BS->Peek1(Bits);
 }
 
 //---------------------------------------------------------------------------
-void File__Analyze::Peek_S2(size_t Bits, int16u &Info)
+void File__Analyze::Peek_S2(int8u Bits, int16u &Info)
 {
     INTEGRITY_INT(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
     Info=BS->Peek2(Bits);
 }
 
 //---------------------------------------------------------------------------
-void File__Analyze::Peek_S3(size_t Bits, int32u &Info)
+void File__Analyze::Peek_S3(int8u Bits, int32u &Info)
 {
     INTEGRITY_INT(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
     Info=BS->Peek4(Bits);
 }
 
 //---------------------------------------------------------------------------
-void File__Analyze::Peek_S4(size_t Bits, int32u &Info)
+void File__Analyze::Peek_S4(int8u Bits, int32u &Info)
 {
     INTEGRITY_INT(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
     Info=BS->Peek4(Bits);
 }
 
 //---------------------------------------------------------------------------
-void File__Analyze::Peek_S5(size_t Bits, int64u &Info)
+void File__Analyze::Peek_S5(int8u Bits, int64u &Info)
 {
     INTEGRITY_INT(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
     Info=BS->Peek8(Bits);
 }
 
 //---------------------------------------------------------------------------
-void File__Analyze::Peek_S6(size_t Bits, int64u &Info)
+void File__Analyze::Peek_S6(int8u Bits, int64u &Info)
 {
     INTEGRITY_INT(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
     Info=BS->Peek8(Bits);
 }
 
 //---------------------------------------------------------------------------
-void File__Analyze::Peek_S7(size_t Bits, int64u &Info)
+void File__Analyze::Peek_S7(int8u Bits, int64u &Info)
 {
     INTEGRITY_INT(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
     Info=BS->Peek8(Bits);
 }
 
 //---------------------------------------------------------------------------
-void File__Analyze::Peek_S8(size_t Bits, int64u &Info)
+void File__Analyze::Peek_S8(int8u Bits, int64u &Info)
 {
     INTEGRITY_INT(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
     Info=BS->Peek8(Bits);
@@ -2041,7 +2031,7 @@ void File__Analyze::Skip_BS(size_t Bits, const char* Name)
     if (Trace_Activated)
     {
         if (Bits<=32) //TODO: in BitStream.h, handle >32 bit gets
-            Param(Name, BS->Get4(Bits));
+            Param(Name, BS->Get4((int8u)Bits));
         else
         {
             Param(Name, "(Data)");
@@ -2063,7 +2053,7 @@ void File__Analyze::Skip_SB(              const char* Name)
 }
 
 //---------------------------------------------------------------------------
-void File__Analyze::Skip_S1(size_t Bits, const char* Name)
+void File__Analyze::Skip_S1(int8u Bits, const char* Name)
 {
     INTEGRITY(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
     if (Trace_Activated)
@@ -2076,7 +2066,7 @@ void File__Analyze::Skip_S1(size_t Bits, const char* Name)
 }
 
 //---------------------------------------------------------------------------
-void File__Analyze::Skip_S2(size_t Bits, const char* Name)
+void File__Analyze::Skip_S2(int8u Bits, const char* Name)
 {
     INTEGRITY(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
     if (Trace_Activated)
@@ -2086,7 +2076,7 @@ void File__Analyze::Skip_S2(size_t Bits, const char* Name)
 }
 
 //---------------------------------------------------------------------------
-void File__Analyze::Skip_S3(size_t Bits, const char* Name)
+void File__Analyze::Skip_S3(int8u Bits, const char* Name)
 {
     INTEGRITY(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
     if (Trace_Activated)
@@ -2096,7 +2086,7 @@ void File__Analyze::Skip_S3(size_t Bits, const char* Name)
 }
 
 //---------------------------------------------------------------------------
-void File__Analyze::Skip_S4(size_t Bits, const char* Name)
+void File__Analyze::Skip_S4(int8u Bits, const char* Name)
 {
     INTEGRITY(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
     if (Trace_Activated)
@@ -2106,7 +2096,7 @@ void File__Analyze::Skip_S4(size_t Bits, const char* Name)
 }
 
 //---------------------------------------------------------------------------
-void File__Analyze::Skip_S5(size_t Bits, const char* Name)
+void File__Analyze::Skip_S5(int8u Bits, const char* Name)
 {
     INTEGRITY(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
     if (Trace_Activated)
@@ -2116,7 +2106,7 @@ void File__Analyze::Skip_S5(size_t Bits, const char* Name)
 }
 
 //---------------------------------------------------------------------------
-void File__Analyze::Skip_S6(size_t Bits, const char* Name)
+void File__Analyze::Skip_S6(int8u Bits, const char* Name)
 {
     INTEGRITY(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
     if (Trace_Activated)
@@ -2126,7 +2116,7 @@ void File__Analyze::Skip_S6(size_t Bits, const char* Name)
 }
 
 //---------------------------------------------------------------------------
-void File__Analyze::Skip_S7(size_t Bits, const char* Name)
+void File__Analyze::Skip_S7(int8u Bits, const char* Name)
 {
     INTEGRITY(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
     if (Trace_Activated)
@@ -2136,7 +2126,7 @@ void File__Analyze::Skip_S7(size_t Bits, const char* Name)
 }
 
 //---------------------------------------------------------------------------
-void File__Analyze::Skip_S8(size_t Bits, const char* Name)
+void File__Analyze::Skip_S8(int8u Bits, const char* Name)
 {
     INTEGRITY(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
     if (Trace_Activated)
@@ -2233,14 +2223,6 @@ void File__Analyze::Get_T2(size_t Bits, int16u &Info, const char* Name)
     if (Trace_Activated) Param(Name, Info);
 }
 
-//---------------------------------------------------------------------------
-void File__Analyze::Get_T3(size_t Bits, int32u &Info, const char* Name)
-{
-    INTEGRITY_INT(Bits<=BT->Remain(), "Size is wrong", BT->Offset_Get())
-    Info=BT->Get4(Bits);
-    if (Trace_Activated) Param(Name, Info);
-}
-
 //---------------------------------------------------------------------------
 void File__Analyze::Get_T4(size_t Bits, int32u &Info, const char* Name)
 {
@@ -2249,30 +2231,6 @@ void File__Analyze::Get_T4(size_t Bits, int32u &Info, const char* Name)
     if (Trace_Activated) Param(Name, Info);
 }
 
-//---------------------------------------------------------------------------
-void File__Analyze::Get_T5(size_t Bits, int64u &Info, const char* Name)
-{
-    INTEGRITY_INT(Bits<=BT->Remain(), "Size is wrong", BT->Offset_Get())
-    Info=BT->Get8(Bits);
-    if (Trace_Activated) Param(Name, Info);
-}
-
-//---------------------------------------------------------------------------
-void File__Analyze::Get_T6(size_t Bits, int64u &Info, const char* Name)
-{
-    INTEGRITY_INT(Bits<=BT->Remain(), "Size is wrong", BT->Offset_Get())
-    Info=BT->Get8(Bits);
-    if (Trace_Activated) Param(Name, Info);
-}
-
-//---------------------------------------------------------------------------
-void File__Analyze::Get_T7(size_t Bits, int64u &Info, const char* Name)
-{
-    INTEGRITY_INT(Bits<=BT->Remain(), "Size is wrong", BT->Offset_Get())
-    Info=BT->Get8(Bits);
-    if (Trace_Activated) Param(Name, Info);
-}
-
 //---------------------------------------------------------------------------
 void File__Analyze::Get_T8(size_t Bits, int64u &Info, const char* Name)
 {
@@ -2309,13 +2267,6 @@ void File__Analyze::Peek_T2(size_t Bits, int16u &Info)
     Info=BT->Peek2(Bits);
 }
 
-//---------------------------------------------------------------------------
-void File__Analyze::Peek_T3(size_t Bits, int32u &Info)
-{
-    INTEGRITY_INT(Bits<=BT->Remain(), "Size is wrong", BT->Offset_Get())
-    Info=BT->Peek4(Bits);
-}
-
 //---------------------------------------------------------------------------
 void File__Analyze::Peek_T4(size_t Bits, int32u &Info)
 {
@@ -2323,27 +2274,6 @@ void File__Analyze::Peek_T4(size_t Bits, int32u &Info)
     Info=BT->Peek4(Bits);
 }
 
-//---------------------------------------------------------------------------
-void File__Analyze::Peek_T5(size_t Bits, int64u &Info)
-{
-    INTEGRITY_INT(Bits<=BT->Remain(), "Size is wrong", BT->Offset_Get())
-    Info=BT->Peek8(Bits);
-}
-
-//---------------------------------------------------------------------------
-void File__Analyze::Peek_T6(size_t Bits, int64u &Info)
-{
-    INTEGRITY_INT(Bits<=BT->Remain(), "Size is wrong", BT->Offset_Get())
-    Info=BT->Peek8(Bits);
-}
-
-//---------------------------------------------------------------------------
-void File__Analyze::Peek_T7(size_t Bits, int64u &Info)
-{
-    INTEGRITY_INT(Bits<=BT->Remain(), "Size is wrong", BT->Offset_Get())
-    Info=BT->Peek8(Bits);
-}
-
 //---------------------------------------------------------------------------
 void File__Analyze::Peek_T8(size_t Bits, int64u &Info)
 {
@@ -2402,16 +2332,6 @@ void File__Analyze::Skip_T2(size_t Bits, const char* Name)
         BT->Skip2(Bits);
 }
 
-//---------------------------------------------------------------------------
-void File__Analyze::Skip_T3(size_t Bits, const char* Name)
-{
-    INTEGRITY(Bits<=BT->Remain(), "Size is wrong", BT->Offset_Get())
-    if (Trace_Activated)
-        Param(Name, BT->Get4(Bits));
-    else
-        BT->Skip4(Bits);
-}
-
 //---------------------------------------------------------------------------
 void File__Analyze::Skip_T4(size_t Bits, const char* Name)
 {
@@ -2422,36 +2342,6 @@ void File__Analyze::Skip_T4(size_t Bits, const char* Name)
         BT->Skip4(Bits);
 }
 
-//---------------------------------------------------------------------------
-void File__Analyze::Skip_T5(size_t Bits, const char* Name)
-{
-    INTEGRITY(Bits<=BT->Remain(), "Size is wrong", BT->Offset_Get())
-    if (Trace_Activated)
-        Param(Name, BT->Get8(Bits));
-    else
-        BT->Skip8(Bits);
-}
-
-//---------------------------------------------------------------------------
-void File__Analyze::Skip_T6(size_t Bits, const char* Name)
-{
-    INTEGRITY(Bits<=BT->Remain(), "Size is wrong", BT->Offset_Get())
-    if (Trace_Activated)
-        Param(Name, BT->Get8(Bits));
-    else
-        BT->Skip8(Bits);
-}
-
-//---------------------------------------------------------------------------
-void File__Analyze::Skip_T7(size_t Bits, const char* Name)
-{
-    INTEGRITY(Bits<=BT->Remain(), "Size is wrong", BT->Offset_Get())
-    if (Trace_Activated)
-        Param(Name, BT->Get8(Bits));
-    else
-        BT->Skip8(Bits);
-}
-
 //---------------------------------------------------------------------------
 void File__Analyze::Skip_T8(size_t Bits, const char* Name)
 {
@@ -2464,4 +2354,3 @@ void File__Analyze::Skip_T8(size_t Bits, const char* Name)
 
 } //NameSpace
 #endif //MEDIAINFO_TRACE
-
