@@ -20,11 +20,23 @@
 #include "MediaInfo/File__MultipleParsing.h"
 //---------------------------------------------------------------------------
 // Multiple
+#if defined(MEDIAINFO_AAF_YES)
+    #include "MediaInfo/Multiple/File_Aaf.h"
+#endif
 #if defined(MEDIAINFO_CDXA_YES)
     #include "MediaInfo/Multiple/File_Cdxa.h"
 #endif
+#if defined(MEDIAINFO_DASHMPD_YES)
+    #include "MediaInfo/Multiple/File_DashMpd.h"
+#endif
 #if defined(MEDIAINFO_DCP_YES)
-    #include "MediaInfo/Multiple/File_Dcp.h"
+    #include "MediaInfo/Multiple/File_DcpAm.h"
+#endif
+#if defined(MEDIAINFO_DCP_YES)
+    #include "MediaInfo/Multiple/File_DcpCpl.h"
+#endif
+#if defined(MEDIAINFO_DCP_YES)
+    #include "MediaInfo/Multiple/File_DcpPkl.h"
 #endif
 #if defined(MEDIAINFO_DPG_YES)
     #include "MediaInfo/Multiple/File_Dpg.h"
@@ -44,6 +56,9 @@
 #if defined(MEDIAINFO_GXF_YES)
     #include "MediaInfo/Multiple/File_Gxf.h"
 #endif
+#if defined(MEDIAINFO_HDSF4M_YES)
+    #include "MediaInfo/Multiple/File_HdsF4m.h"
+#endif
 #if defined(MEDIAINFO_HLS_YES)
     #include "MediaInfo/Multiple/File_Hls.h"
 #endif
@@ -83,6 +98,9 @@
 #if defined(MEDIAINFO_PMP_YES)
     #include "MediaInfo/Multiple/File_Pmp.h"
 #endif
+#if defined(MEDIAINFO_PTX_YES)
+    #include "MediaInfo/Multiple/File_Ptx.h"
+#endif
 #if defined(MEDIAINFO_RIFF_YES)
     #include "MediaInfo/Multiple/File_Riff.h"
 #endif
@@ -338,14 +356,26 @@ File__MultipleParsing::File__MultipleParsing()
     #endif //MEDIAINFO_TRACE
 
     // Multiple
+    #if defined(MEDIAINFO_AAF_YES)
+        Parser.push_back(new File_Aaf());
+    #endif
     #if defined(MEDIAINFO_BDAV_YES)
         {File_MpegTs* Temp=new File_MpegTs(); Temp->BDAV_Size=4; Parser.push_back(Temp);}
     #endif
     #if defined(MEDIAINFO_CDXA_YES)
         Parser.push_back(new File_Cdxa());
     #endif
+    #if defined(MEDIAINFO_DASHMPD_YES)
+        Parser.push_back(new File_DashMpd());
+    #endif
     #if defined(MEDIAINFO_DCP_YES)
-        Parser.push_back(new File_Dcp());
+        Parser.push_back(new File_DcpAm());
+    #endif
+    #if defined(MEDIAINFO_DCP_YES)
+        Parser.push_back(new File_DcpCpl());
+    #endif
+    #if defined(MEDIAINFO_DCP_YES)
+        Parser.push_back(new File_DcpPkl());
     #endif
     #if defined(MEDIAINFO_DPG_YES)
         Parser.push_back(new File_Dpg());
@@ -365,6 +395,9 @@ File__MultipleParsing::File__MultipleParsing()
     #if defined(MEDIAINFO_GXF_YES)
         Parser.push_back(new File_Gxf());
     #endif
+    #if defined(MEDIAINFO_HDSF4M_YES)
+        Parser.push_back(new File_HdsF4m());
+    #endif
     #if defined(MEDIAINFO_HLS_YES)
         Parser.push_back(new File_Hls());
     #endif
