@@ -1,20 +1,9 @@
-// MediaInfo_Config - Configuration class
-// Copyright (C) 2005-2012 MediaArea.net SARL, Info@MediaArea.net
-//
-// This library is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Library General Public License as published by
-// the Free Software Foundation, either version 2 of the License, or
-// any later version.
-//
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public License
-// along with this library. If not, see <http://www.gnu.org/licenses/>.
-//
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+/*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
+ *
+ *  Use of this source code is governed by a BSD-style license that can
+ *  be found in the License.html file in the root of the source tree.
+ */
+
 //+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 //
 // Global configuration of MediaInfo
@@ -26,6 +15,10 @@
 #define MediaInfo_ConfigH
 //---------------------------------------------------------------------------
 
+//---------------------------------------------------------------------------
+#include "MediaInfo/Setup.h"
+//---------------------------------------------------------------------------
+
 //---------------------------------------------------------------------------
 #include "MediaInfo/MediaInfo_Internal_Const.h"
 #if MEDIAINFO_EVENTS
@@ -35,10 +28,12 @@
 #include "ZenLib/ZtringListList.h"
 #include "ZenLib/Translation.h"
 #include "ZenLib/InfoMap.h"
-#include <map>
-#include <vector>
 #include <bitset>
 using namespace ZenLib;
+using std::vector;
+using std::string;
+using std::map;
+using std::make_pair;
 //---------------------------------------------------------------------------
 
 namespace MediaInfoLib
@@ -52,6 +47,7 @@ class MediaInfo_Config
 {
 public :
     //Constructor/Destructor
+    MediaInfo_Config() {}
     void Init(); //Must be called instead of constructor
 
     //General
@@ -86,6 +82,9 @@ public :
           void      LegacyStreamDisplay_Set (bool Value);
           bool      LegacyStreamDisplay_Get ();
 
+          void      SkipBinaryData_Set (bool Value);
+          bool      SkipBinaryData_Get ();
+
           void      ParseSpeed_Set (float32 NewValue);
           float32   ParseSpeed_Get ();
 
@@ -147,7 +146,6 @@ public :
           Ztring    Inform_Get (const Ztring &Value);
 
           void      Inform_Replace_Set (const ZtringListList &NewInform_Replace);
-          Ztring    Inform_Replace_Get ();
           ZtringListList Inform_Replace_Get_All ();
 
     const Ztring   &Format_Get (const Ztring &Value, infoformat_t KindOfFormatInfo=InfoFormat_Name);
@@ -168,7 +166,7 @@ public :
     const Ztring   &Info_Get (stream_t KindOfStream, size_t Pos, info_t KindOfInfo=Info_Text);
     const ZtringListList &Info_Get(stream_t KindOfStream); //Should not be, but too difficult to hide it
 
-          Ztring    Info_Parameters_Get ();
+          Ztring    Info_Parameters_Get (bool Complete=false);
           Ztring    Info_Tags_Get       () const;
           Ztring    Info_CodecsID_Get   ();
           Ztring    Info_Codecs_Get     ();
@@ -181,12 +179,31 @@ public :
           void      FormatDetection_MaximumOffset_Set (int64u Value);
           int64u    FormatDetection_MaximumOffset_Get ();
 
+    #if MEDIAINFO_ADVANCED
+          void      VariableGopDetection_Occurences_Set (int64u Value);
+          int64u    VariableGopDetection_Occurences_Get ();
+          void      VariableGopDetection_GiveUp_Set (bool Value);
+          bool      VariableGopDetection_GiveUp_Get ();
+          void      InitDataNotRepeated_Occurences_Set (int64u Value);
+          int64u    InitDataNotRepeated_Occurences_Get ();
+          void      InitDataNotRepeated_GiveUp_Set (bool Value);
+          bool      InitDataNotRepeated_GiveUp_Get ();
+    #endif //MEDIAINFO_ADVANCED
+
           void      MpegTs_MaximumOffset_Set (int64u Value);
           int64u    MpegTs_MaximumOffset_Get ();
           void      MpegTs_MaximumScanDuration_Set (int64u Value);
           int64u    MpegTs_MaximumScanDuration_Get ();
           void      MpegTs_ForceStreamDisplay_Set (bool Value);
           bool      MpegTs_ForceStreamDisplay_Get ();
+    #if MEDIAINFO_ADVANCED
+          void      MpegTs_VbrDetection_Delta_Set (float64 Value);
+          float64   MpegTs_VbrDetection_Delta_Get ();
+          void      MpegTs_VbrDetection_Occurences_Set (int64u Value);
+          int64u    MpegTs_VbrDetection_Occurences_Get ();
+          void      MpegTs_VbrDetection_GiveUp_Set (bool Value);
+          bool      MpegTs_VbrDetection_GiveUp_Get ();
+    #endif //MEDIAINFO_ADVANCED
 
     ZtringListList  SubFile_Config_Get ();
 
@@ -235,10 +252,21 @@ public :
     #endif //defined(MEDIAINFO_LIBCURL_YES)
 
 private :
-    int64u          MpegTs_MaximumScanDuration;
     int64u          FormatDetection_MaximumOffset;
+    #if MEDIAINFO_ADVANCED
+        int64u      VariableGopDetection_Occurences;
+        bool        VariableGopDetection_GiveUp;
+        int64u      InitDataNotRepeated_Occurences;
+        bool        InitDataNotRepeated_GiveUp;
+    #endif //MEDIAINFO_ADVANCED
     int64u          MpegTs_MaximumOffset;
+    int64u          MpegTs_MaximumScanDuration;
     bool            MpegTs_ForceStreamDisplay;
+    #if MEDIAINFO_ADVANCED
+        float64     MpegTs_VbrDetection_Delta;
+        int64u      MpegTs_VbrDetection_Occurences;
+        bool        MpegTs_VbrDetection_GiveUp;
+    #endif //MEDIAINFO_ADVANCED
     size_t          Complete;
     size_t          BlockMethod;
     size_t          Internet;
@@ -258,6 +286,7 @@ private :
     bool            Language_Raw;
     bool            ReadByHuman;
     bool            LegacyStreamDisplay;
+    bool            SkipBinaryData;
     int8u           Demux;
     Ztring          Version;
     Ztring          ColumnSeparator;
@@ -267,7 +296,7 @@ private :
     Ztring          DecimalPoint;
     Ztring          ThousandsPoint;
     Translation     Language; //ex. : "KB;Ko"
-    ZtringListList  Custom_View; //Definition of "General", "Video", "Audio", "Text", "Chapters", "Image"
+    ZtringListList  Custom_View; //Definition of "General", "Video", "Audio", "Text", "Other", "Image"
     ZtringListList  Custom_View_Replace; //ToReplace;ReplaceBy
     trace_Format    Trace_Format;
 
@@ -308,6 +337,10 @@ private :
           Ztring    Ssl_CertificateRevocationListFileName;
           bool      Ssl_IgnoreSecurity;
     #endif //defined(MEDIAINFO_LIBCURL_YES)
+
+    //Constructor
+    MediaInfo_Config (const MediaInfo_Config&);             // Prevent copy-construction
+    MediaInfo_Config& operator=(const MediaInfo_Config&);   // Prevent assignment
 };
 
 extern MediaInfo_Config Config;
