@@ -1,20 +1,9 @@
-// MediaInfo_Config - Configuration class
-// Copyright (C) 2005-2012 Jerome Martinez, Zen@MediaArea.net
-//
-// This library is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Library General Public License as published by
-// the Free Software Foundation, either version 2 of the License, or
-// any later version.
-//
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public License
-// along with this library. If not, see <http://www.gnu.org/licenses/>.
-//
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+/*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
+ *
+ *  Use of this source code is governed by a BSD-style license that can
+ *  be found in the License.html file in the root of the source tree.
+ */
+
 //+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 //
 // Global configuration of MediaInfo
@@ -74,7 +63,7 @@ enum stream_t
     Stream_Video,                   ///< StreamKind = Video
     Stream_Audio,                   ///< StreamKind = Audio
     Stream_Text,                    ///< StreamKind = Text
-    Stream_Chapters,                ///< StreamKind = Chapters
+    Stream_Other,                   ///< StreamKind = Chapters
     Stream_Image,                   ///< StreamKind = Image
     Stream_Menu,                    ///< StreamKind = Menu
     Stream_Max
@@ -124,18 +113,18 @@ enum fileoptions_t
 #undef  __T
 #define __T(__x)     __T(__x)
 #if defined(UNICODE) || defined (_UNICODE)
-    typedef wchar_t Char;
+    typedef wchar_t Char;                                               ///< Unicode/Ansi independant char
     #undef  __T
     #define __T(__x) L ## __x
 #else
-    typedef char Char;
+    typedef char Char;                                                  ///< Unicode/Ansi independant char
     #undef  __T
     #define __T(__x) __x
 #endif
-typedef std::basic_string<MediaInfoLib::Char>        String;
-typedef std::basic_stringstream<MediaInfoLib::Char>  StringStream;
-typedef std::basic_istringstream<MediaInfoLib::Char> tiStringStream;
-typedef std::basic_ostringstream<MediaInfoLib::Char> toStringStream;
+typedef std::basic_string<MediaInfoLib::Char>        String;            ///< Unicode/Ansi independant string
+typedef std::basic_stringstream<MediaInfoLib::Char>  StringStream;      ///< Unicode/Ansi independant stringstream
+typedef std::basic_istringstream<MediaInfoLib::Char> tiStringStream;    ///< Unicode/Ansi independant istringstream
+typedef std::basic_ostringstream<MediaInfoLib::Char> toStringStream;    ///< Unicode/Ansi independant ostringstream
 //---------------------------------------------------------------------------
 
 } //NameSpace
