@@ -384,6 +384,12 @@ struct MediaInfo_Event_General_SubFile_End_0
 /* MPEG-TS / BDAV / TSP                                                    */
 /***************************************************************************/
 
+#define MediaInfo_Parser_SideCar        0x72
+
+/***************************************************************************/
+/* MPEG-TS / BDAV / TSP                                                    */
+/***************************************************************************/
+
 #define MediaInfo_Parser_MpegTs         0x01
 
 /***************************************************************************/
@@ -492,6 +498,54 @@ struct MediaInfo_Event_DvDif_Analysis_Frame_0
 
 #define MediaInfo_Parser_Ism            0x62
 
+/***************************************************************************/
+/* DASH MPD                                                                */
+/***************************************************************************/
+
+#define MediaInfo_Parser_DashMpd        0x63
+
+/***************************************************************************/
+/* HDS F4M                                                                 */
+/***************************************************************************/
+
+#define MediaInfo_Parser_HdsF4m         0x64
+
+/***************************************************************************/
+/* DCP Composition Asset Map                                               */
+/***************************************************************************/
+
+#define MediaInfo_Parser_DcpAm          0x65
+
+/***************************************************************************/
+/* DCP Composition Playlist                                                */
+/***************************************************************************/
+
+#define MediaInfo_Parser_DcpCpl         0x66
+
+/***************************************************************************/
+/* DCP Package List                                                        */
+/***************************************************************************/
+
+#define MediaInfo_Parser_DcpPkl         0x67
+
+/***************************************************************************/
+/* DCP Output List                                                        */
+/***************************************************************************/
+
+#define MediaInfo_Parser_DcpOpl         0x68
+
+/***************************************************************************/
+/* Pro Tools session 10                                                    */
+/***************************************************************************/
+
+#define MediaInfo_Parser_Ptx            0x69
+
+/***************************************************************************/
+/* AAF                                                                     */
+/***************************************************************************/
+
+#define MediaInfo_Parser_Aaf            0x6A
+
 /***************************************************************************/
 /* MPEG Video                                                              */
 /***************************************************************************/
@@ -643,4 +697,22 @@ struct MediaInfo_Event_DvDif_Analysis_Frame_0
 
 #define MediaInfo_Parser_AribStdB24B37  0xF9
 
+/***************************************************************************/
+/* TTML                                                                    */
+/***************************************************************************/
+
+#define MediaInfo_Parser_Ttml           0xFA
+
+/***************************************************************************/
+/* SubRip                                                                  */
+/***************************************************************************/
+
+#define MediaInfo_Parser_SubRip         0xFB
+
+/***************************************************************************/
+/* N19                                                                     */
+/***************************************************************************/
+
+#define MediaInfo_Parser_N19            0xFC
+
 #endif //MediaInfo_EventsH
