@@ -29,14 +29,26 @@
 
 //---------------------------------------------------------------------------
 // Multiple
+#if defined(MEDIAINFO_AAF_YES)
+    #include "MediaInfo/Multiple/File_Aaf.h"
+#endif
 #if defined(MEDIAINFO_BDMV_YES)
     #include "MediaInfo/Multiple/File_Bdmv.h"
 #endif
 #if defined(MEDIAINFO_CDXA_YES)
     #include "MediaInfo/Multiple/File_Cdxa.h"
 #endif
+#if defined(MEDIAINFO_DASHMPD_YES)
+    #include "MediaInfo/Multiple/File_DashMpd.h"
+#endif
 #if defined(MEDIAINFO_DCP_YES)
-    #include "MediaInfo/Multiple/File_Dcp.h"
+    #include "MediaInfo/Multiple/File_DcpAm.h"
+#endif
+#if defined(MEDIAINFO_DCP_YES)
+    #include "MediaInfo/Multiple/File_DcpCpl.h"
+#endif
+#if defined(MEDIAINFO_DCP_YES)
+    #include "MediaInfo/Multiple/File_DcpPkl.h"
 #endif
 #if defined(MEDIAINFO_DVDIF_YES)
     #include "MediaInfo/Multiple/File_DvDif.h"
@@ -53,6 +65,9 @@
 #if defined(MEDIAINFO_GXF_YES)
     #include "MediaInfo/Multiple/File_Gxf.h"
 #endif
+#if defined(MEDIAINFO_HDSF4M_YES)
+    #include "MediaInfo/Multiple/File_HdsF4m.h"
+#endif
 #if defined(MEDIAINFO_HLS_YES)
     #include "MediaInfo/Multiple/File_Hls.h"
 #endif
@@ -62,6 +77,9 @@
 #if defined(MEDIAINFO_ISM_YES)
     #include "MediaInfo/Multiple/File_Ism.h"
 #endif
+#if defined(MEDIAINFO_IMF_YES)
+    #include "MediaInfo/Multiple/File_ImfCpl.h"
+#endif
 #if defined(MEDIAINFO_IVF_YES)
     #include "MediaInfo/Multiple/File_Ivf.h"
 #endif
@@ -95,6 +113,9 @@
 #if defined(MEDIAINFO_PMP_YES)
     #include "MediaInfo/Multiple/File_Pmp.h"
 #endif
+#if defined(MEDIAINFO_PTX_YES)
+    #include "MediaInfo/Multiple/File_Ptx.h"
+#endif
 #if defined(MEDIAINFO_RIFF_YES)
     #include "MediaInfo/Multiple/File_Riff.h"
 #endif
@@ -359,6 +380,9 @@ bool MediaInfo_Internal::SelectFromExtension (const String &Parser)
              if (0) {} //For #defines
 
     // Multiple
+    #if defined(MEDIAINFO_AAF_YES)
+        else if (Parser==__T("Aaf"))        Info=new File_Aaf();
+    #endif
     #if defined(MEDIAINFO_BDAV_YES)
         else if (Parser==__T("Bdav"))       {Info=new File_MpegTs(); ((File_MpegTs*)Info)->BDAV_Size=4;}
     #endif
@@ -368,8 +392,17 @@ bool MediaInfo_Internal::SelectFromExtension (const String &Parser)
     #if defined(MEDIAINFO_CDXA_YES)
         else if (Parser==__T("Cdxa"))        Info=new File_Cdxa();
     #endif
+    #if defined(MEDIAINFO_DASHMPD_YES)
+        else if (Parser==__T("DashMpd"))     Info=new File_DashMpd();
+    #endif
     #if defined(MEDIAINFO_DCP_YES)
-        else if (Parser==__T("Dcp"))         Info=new File_Dcp();
+        else if (Parser==__T("DcpAm"))       Info=new File_DcpAm();
+    #endif
+    #if defined(MEDIAINFO_DCP_YES)
+        else if (Parser==__T("DcpCpl"))      Info=new File_DcpCpl();
+    #endif
+    #if defined(MEDIAINFO_DCP_YES)
+        else if (Parser==__T("DcpPkg"))      Info=new File_DcpPkl();
     #endif
     #if defined(MEDIAINFO_DVDIF_YES)
         else if (Parser==__T("DvDif"))        Info=new File_DvDif();
@@ -386,6 +419,9 @@ bool MediaInfo_Internal::SelectFromExtension (const String &Parser)
     #if defined(MEDIAINFO_GXF_YES)
         else if (Parser==__T("Gxf"))         Info=new File_Gxf();
     #endif
+    #if defined(MEDIAINFO_HDSF4M_YES)
+        else if (Parser==__T("HdsF4m"))      Info=new File_HdsF4m();
+    #endif
     #if defined(MEDIAINFO_HLS_YES)
         else if (Parser==__T("Hls"))         Info=new File_Hls();
     #endif
@@ -425,6 +461,9 @@ bool MediaInfo_Internal::SelectFromExtension (const String &Parser)
     #if defined(MEDIAINFO_PMP_YES)
         else if (Parser==__T("Pmp"))         Info=new File_Pmp();
     #endif
+    #if defined(MEDIAINFO_PTX_YES)
+        else if (Parser==__T("Ptx"))         Info=new File_Ptx();
+    #endif
     #if defined(MEDIAINFO_RIFF_YES)
         else if (Parser==__T("Riff"))        Info=new File_Riff();
     #endif
@@ -670,6 +709,9 @@ bool MediaInfo_Internal::SelectFromExtension (const String &Parser)
 int MediaInfo_Internal::ListFormats(const String &File_Name)
 {
     // Multiple
+    #if defined(MEDIAINFO_AAF_YES)
+        delete Info; Info=new File_Aaf();                if (((Reader_File*)Reader)->Format_Test_PerParser(this, File_Name)>0) return 1;
+    #endif
     #if defined(MEDIAINFO_BDAV_YES)
         delete Info; Info=new File_MpegTs(); ((File_MpegTs*)Info)->BDAV_Size=4; if (((Reader_File*)Reader)->Format_Test_PerParser(this, File_Name)>0) return 1;
     #endif
@@ -679,8 +721,17 @@ int MediaInfo_Internal::ListFormats(const String &File_Name)
     #if defined(MEDIAINFO_CDXA_YES)
         delete Info; Info=new File_Cdxa();               if (((Reader_File*)Reader)->Format_Test_PerParser(this, File_Name)>0) return 1;
     #endif
+    #if defined(MEDIAINFO_DASHMPD_YES)
+        delete Info; Info=new File_DashMpd();            if (((Reader_File*)Reader)->Format_Test_PerParser(this, File_Name)>0) return 1;
+    #endif
     #if defined(MEDIAINFO_DCP_YES)
-        delete Info; Info=new File_Dcp();                if (((Reader_File*)Reader)->Format_Test_PerParser(this, File_Name)>0) return 1;
+        delete Info; Info=new File_DcpAm();              if (((Reader_File*)Reader)->Format_Test_PerParser(this, File_Name)>0) return 1;
+    #endif
+    #if defined(MEDIAINFO_DCP_YES)
+        delete Info; Info=new File_DcpCpl();             if (((Reader_File*)Reader)->Format_Test_PerParser(this, File_Name)>0) return 1;
+    #endif
+    #if defined(MEDIAINFO_DCP_YES)
+        delete Info; Info=new File_DcpPkl();             if (((Reader_File*)Reader)->Format_Test_PerParser(this, File_Name)>0) return 1;
     #endif
     #if defined(MEDIAINFO_DVDIF_YES)
         delete Info; Info=new File_DvDif();              if (((Reader_File*)Reader)->Format_Test_PerParser(this, File_Name)>0) return 1;
@@ -697,6 +748,9 @@ int MediaInfo_Internal::ListFormats(const String &File_Name)
     #if defined(MEDIAINFO_GXF_YES)
         delete Info; Info=new File_Gxf();                if (((Reader_File*)Reader)->Format_Test_PerParser(this, File_Name)>0) return 1;
     #endif
+    #if defined(MEDIAINFO_HDSF4M_YES)
+        delete Info; Info=new File_HdsF4m();             if (((Reader_File*)Reader)->Format_Test_PerParser(this, File_Name)>0) return 1;
+    #endif
     #if defined(MEDIAINFO_HLS_YES)
         delete Info; Info=new File_Hls();                if (((Reader_File*)Reader)->Format_Test_PerParser(this, File_Name)>0) return 1;
     #endif
@@ -742,6 +796,9 @@ int MediaInfo_Internal::ListFormats(const String &File_Name)
     #if defined(MEDIAINFO_PMP_YES)
         delete Info; Info=new File_Pmp();                if (((Reader_File*)Reader)->Format_Test_PerParser(this, File_Name)>0) return 1;
     #endif
+    #if defined(MEDIAINFO_PTX_YES)
+        delete Info; Info=new File_Ptx();                if (((Reader_File*)Reader)->Format_Test_PerParser(this, File_Name)>0) return 1;
+    #endif
     #if defined(MEDIAINFO_RIFF_YES)
         delete Info; Info=new File_Riff();               if (((Reader_File*)Reader)->Format_Test_PerParser(this, File_Name)>0) return 1;
     #endif
@@ -979,7 +1036,7 @@ int MediaInfo_Internal::ListFormats(const String &File_Name)
 bool MediaInfo_Internal::LibraryIsModified ()
 {
     #if defined(MEDIAINFO_MULTI_NO) || defined(MEDIAINFO_VIDEO_NO) || defined(MEDIAINFO_AUDIO_NO) || defined(MEDIAINFO_TEXT_NO) || defined(MEDIAINFO_IMAGE_NO) || defined(MEDIAINFO_ARCHIVE_NO) \
-     || defined(MEDIAINFO_BDAV_NO) || defined(MEDIAINFO_MK_NO) || defined(MEDIAINFO_OGG_NO) || defined(MEDIAINFO_RIFF_NO) || defined(MEDIAINFO_MPEG4_NO) || defined(MEDIAINFO_MPEGPS_NO) || defined(MEDIAINFO_MPEGTS_NO) || defined(MEDIAINFO_DXW_NO) || defined(MEDIAINFO_FLV_NO) || defined(MEDIAINFO_GXF_NO) || defined(MEDIAINFO_HLS_NO) || defined(MEDIAINFO_ISM_NO) || defined(MEDIAINFO_IVF_NO) || defined(MEDIAINFO_LXF_NO) || defined(MEDIAINFO_SWF_NO) || defined(MEDIAINFO_MXF_NO) || defined(MEDIAINFO_NUT_NO) || defined(MEDIAINFO_WM_NO) || defined(MEDIAINFO_QT_NO) || defined(MEDIAINFO_RM_NO) || defined(MEDIAINFO_DVDIF_NO) || defined(MEDIAINFO_DVDV_NO) || defined(MEDIAINFO_CDXA_NO) || defined(MEDIAINFO_DPG_NO) || defined(MEDIAINFO_TSP_NO) \
+     || defined(MEDIAINFO_BDAV_NO) || defined(MEDIAINFO_MK_NO) || defined(MEDIAINFO_OGG_NO) || defined(MEDIAINFO_RIFF_NO) || defined(MEDIAINFO_MPEG4_NO) || defined(MEDIAINFO_MPEGPS_NO) || defined(MEDIAINFO_MPEGTS_NO) || defined(MEDIAINFO_DXW_NO) || defined(MEDIAINFO_FLV_NO) || defined(MEDIAINFO_GXF_NO) || defined(MEDIAINFO_HDSF4M_NO) || defined(MEDIAINFO_HLS_NO) || defined(MEDIAINFO_ISM_NO) || defined(MEDIAINFO_IVF_NO) || defined(MEDIAINFO_LXF_NO) || defined(MEDIAINFO_SWF_NO) || defined(MEDIAINFO_MXF_NO) || defined(MEDIAINFO_NUT_NO) || defined(MEDIAINFO_WM_NO) || defined(MEDIAINFO_QT_NO) || defined(MEDIAINFO_RM_NO) || defined(MEDIAINFO_DVDIF_NO) || defined(MEDIAINFO_DVDV_NO) || defined(MEDIAINFO_AAF_NO) || defined(MEDIAINFO_CDXA_NO) || defined(MEDIAINFO_DPG_NO) || defined(MEDIAINFO_TSP_NO) \
      || defined(MEDIAINFO_AVC_NO) || defined(MEDIAINFO_AVSV_NO) || defined(MEDIAINFO_HEVC_NO) || defined(MEDIAINFO_MPEG4V_NO) || defined(MEDIAINFO_MPEGV_NO) || defined(MEDIAINFO_FLIC_NO) || defined(MEDIAINFO_THEORA_NO) || defined(MEDIAINFO_Y4M_NO) \
      || defined(MEDIAINFO_AC3_NO) || defined(MEDIAINFO_ADIF_NO) || defined(MEDIAINFO_ADTS_NO) || defined(MEDIAINFO_SMPTEST0337_NO) || defined(MEDIAINFO_AMR_NO) || defined(MEDIAINFO_DTS_NO) || defined(MEDIAINFO_DOLBYE_NO) || defined(MEDIAINFO_FLAC_NO) || defined(MEDIAINFO_APE_NO) || defined(MEDIAINFO_MPC_NO) || defined(MEDIAINFO_MPCSV8_NO) || defined(MEDIAINFO_MPEGA_NO) || defined(MEDIAINFO_TWINVQ_NO) || defined(MEDIAINFO_XM_NO) || defined(MEDIAINFO_MOD_NO) || defined(MEDIAINFO_S3M_NO) || defined(MEDIAINFO_IT_NO) || defined(MEDIAINFO_SPEEX_NO) || defined(MEDIAINFO_TAK_NO) || defined(MEDIAINFO_PS2A_NO) \
      || defined(MEDIAINFO_CMML_NO)  || defined(MEDIAINFO_KATE_NO)  || defined(MEDIAINFO_PGS_NO) || defined(MEDIAINFO_OTHERTEXT_NO) \
