@@ -1,20 +1,9 @@
-// MediaInfo_Inform - Base for other files
-// Copyright (C) 2002-2012 MediaArea.net SARL, Info@MediaArea.net
-//
-// This library is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Library General Public License as published by
-// the Free Software Foundation, either version 2 of the License, or
-// any later version.
-//
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public License
-// along with this library. If not, see <http://www.gnu.org/licenses/>.
-//
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+/*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
+ *
+ *  Use of this source code is governed by a BSD-style license that can
+ *  be found in the License.html file in the root of the source tree.
+ */
+
 //+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 //
 // Inform part
@@ -35,12 +24,12 @@
 
 //---------------------------------------------------------------------------
 #include "ZenLib/Utils.h"
-#include "MediaInfo/MediaInfo_Internal.h"
-#include "MediaInfo/MediaInfo_Config.h"
+#include "MediaInfo/Export/Export_EbuCore.h"
 #include "MediaInfo/Export/Export_Mpeg7.h"
 #include "MediaInfo/Export/Export_reVTMD.h"
 #include "MediaInfo/Export/Export_PBCore.h"
 #include "MediaInfo/File__Analyze.h"
+#include "base64.h"
 //---------------------------------------------------------------------------
 
 namespace MediaInfoLib
@@ -72,6 +61,8 @@ Ztring MediaInfo_Internal::Inform()
         }
     #endif //MEDIAINFO_TRACE
 
+    if (MediaInfoLib::Config.Inform_Get()==__T("EBUCore") || MediaInfoLib::Config.Inform_Get()==__T("EBUCore_1.4"))
+        return Export_EbuCore().Transform(*this);
     if (MediaInfoLib::Config.Inform_Get()==__T("MPEG-7"))
         return Export_Mpeg7().Transform(*this);
     if (MediaInfoLib::Config.Inform_Get()==__T("PBCore") || MediaInfoLib::Config.Inform_Get()==__T("PBCore_1.2"))
@@ -124,15 +115,15 @@ Ztring MediaInfo_Internal::Inform()
         }
         if (Count_Get(Stream_Text))
             Retour+=MediaInfoLib::Config.Inform_Get(__T("Text_End"));
-        if (Count_Get(Stream_Chapters))
+        if (Count_Get(Stream_Other))
             Retour+=MediaInfoLib::Config.Inform_Get(__T("Chapters_Begin"));
-        for (size_t I1=0; I1<Count_Get(Stream_Chapters); I1++)
+        for (size_t I1=0; I1<Count_Get(Stream_Other); I1++)
         {
-            Retour+=Inform(Stream_Chapters, I1, false);
-            if (I1!=Count_Get(Stream_Chapters)-1)
+            Retour+=Inform(Stream_Other, I1, false);
+            if (I1!=Count_Get(Stream_Other)-1)
                 Retour+=MediaInfoLib::Config.Inform_Get(__T("Chapters_Middle"));
         }
-        if (Count_Get(Stream_Chapters))
+        if (Count_Get(Stream_Other))
             Retour+=MediaInfoLib::Config.Inform_Get(__T("Chapters_End"));
         if (Count_Get(Stream_Image))
             Retour+=MediaInfoLib::Config.Inform_Get(__T("Image_Begin"));
@@ -312,12 +303,18 @@ Ztring MediaInfo_Internal::Inform (stream_t StreamKind, size_t StreamPos, bool I
                 else if (XML)
                 {
                     Nom=Xml_Name_Escape(Nom);
-                    Xml_Content_Escape_Modifying(Valeur);
+                    size_t Modified;
+                    Xml_Content_Escape_Modifying(Valeur, Modified);
 
                     Retour+=__T("<");
                     Retour+=Nom;
+                    if (Modified==1 && !MediaInfoLib::Config.SkipBinaryData_Get()) //Base64
+                        Retour+=__T(" dt=\"binary.base64\"");
                     Retour+=__T(">");
-                    Retour+=Valeur;
+                    if (Modified==1 && MediaInfoLib::Config.SkipBinaryData_Get())
+                        Retour+=__T("(Binary data)");
+                    else
+                        Retour+=Valeur;
                     Retour+=__T("</");
                     Retour+=Nom;
                     Retour+=__T(">");
@@ -541,10 +538,10 @@ Ztring MediaInfo_Internal::Xml_Name_Escape (const Ztring &Name)
 }
 
 //---------------------------------------------------------------------------
-Ztring MediaInfo_Internal::Xml_Content_Escape (const Ztring &Content)
+Ztring MediaInfo_Internal::Xml_Content_Escape (const Ztring &Content, size_t &Modified)
 {
     Ztring ToReturn(Content);
-    return Xml_Content_Escape_Modifying(ToReturn);
+    return Xml_Content_Escape_Modifying(ToReturn, Modified);
 }
 
 //---------------------------------------------------------------------------
@@ -570,9 +567,11 @@ size_t Xml_Content_Escape_MustEscape(const Ztring &Content)
 
     return Pos;
 }
-Ztring &MediaInfo_Internal::Xml_Content_Escape_Modifying (Ztring &Content)
+Ztring &MediaInfo_Internal::Xml_Content_Escape_Modifying (Ztring &Content, size_t &Modified)
 {
     size_t Pos=Xml_Content_Escape_MustEscape(Content);
+    Ztring Content_Save=Content;
+    Modified=0;
     if (Pos>=Content.size())
         return Content;
 
@@ -585,7 +584,7 @@ Ztring &MediaInfo_Internal::Xml_Content_Escape_Modifying (Ztring &Content)
                             Content.insert(Pos+1, __T("quot;"));
                             Pos+=5;
                             break;
-            case __T('&') :
+            case __T('&'):
                             Content[Pos]=__T('&');
                             Content.insert(Pos+1, __T("amp;"));
                             Pos+=4;
@@ -595,23 +594,30 @@ Ztring &MediaInfo_Internal::Xml_Content_Escape_Modifying (Ztring &Content)
                             Content.insert(Pos+1, __T("apos;"));
                             Pos+=5;
                             break;
-            case __T('<') :
+            case __T('<'):
                             Content[Pos]=__T('&');
                             Content.insert(Pos+1, __T("lt;"));
                             Pos+=3;
                             break;
-            case __T('>') :
+            case __T('>'):
                             Content[Pos]=__T('&');
                             Content.insert(Pos+1, __T("gt;"));
                             Pos+=3;
                             break;
-            default   :
+            default:
                         if (Content[Pos]<0x20)
                         {
+                            /* Is still invalid XML
                             Ztring Character=__T("#x")+Ztring::ToZtring(Content[Pos]/16, 16)+Ztring::ToZtring(Content[Pos]%16, 16)+__T(";");
                             Content[Pos]=__T('&');
                             Content.insert(Pos+1, Character);
                             Pos+=5;
+                            */
+                            string Content_Utf8=Content_Save.To_UTF8(); //TODO: shouldn't we never convert to Unicode?
+                            string Content_Base64=Base64::encode(Content_Utf8);
+                            Content.From_UTF8(Content_Base64);
+                            Modified=1; //Base64
+                            Pos=Content.size(); //End
                         }
         }
     }
@@ -620,4 +626,3 @@ Ztring &MediaInfo_Internal::Xml_Content_Escape_Modifying (Ztring &Content)
 }
 
 } //NameSpace
-
