@@ -1,21 +1,8 @@
-// File_DvDif - Info for DV-DIF files
-// Copyright (C) 2002-2012 MediaArea.net SARL, Info@MediaArea.net
-//
-// This library is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Library General Public License as published by
-// the Free Software Foundation, either version 2 of the License, or
-// any later version.
-//
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public License
-// along with this library. If not, see <http://www.gnu.org/licenses/>.
-//
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+/*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
+ *
+ *  Use of this source code is governed by a BSD-style license that can
+ *  be found in the License.html file in the root of the source tree.
+ */
 
 //---------------------------------------------------------------------------
 // Pre-compilation
@@ -471,12 +458,13 @@ void File_DvDif::Errors_Stats_Update()
             return;
     }
 
-    bool Errors_AreDetected=false;
-    bool Infos_AreDetected=false;
-    bool Arb_AreDetected=false;
     Ztring Errors_Stats_Line;
     if (Speed_FrameCount) //We must have at least one complete frame
     {
+        bool Errors_AreDetected=false;
+        bool Infos_AreDetected=false;
+        bool Arb_AreDetected=false;
+
         #if MEDIAINFO_EVENTS
             //Demux
             struct MediaInfo_Event_DvDif_Analysis_Frame_0 Event;
@@ -585,8 +573,7 @@ void File_DvDif::Errors_Stats_Update()
             #endif //MEDIAINFO_EVENTS
             if (Speed_TimeCode_Current.Time.Hours
              || Speed_TimeCode_Current.Time.Seconds
-             || Speed_TimeCode_Current.Time.Minutes
-             || Speed_TimeCode_Current.Time.Hours)
+             || Speed_TimeCode_Current.Time.Minutes)
                 Errors_AreDetected=true;
         }
         else if (Speed_TimeCode_IsValid && Speed_TimeCode_Current.IsValid && Speed_TimeCode_Current_Theory.IsValid
@@ -1193,7 +1180,7 @@ void File_DvDif::Errors_Stats_Update()
                 Errors=Errors_Stats_Line_Details.To_Local();
                 Event.Errors=(char*)Errors.c_str();
             }
-            Config->Event_Send((const int8u*)&Event, sizeof(MediaInfo_Event_DvDif_Analysis_Frame_0));
+            Config->Event_Send(this, (const int8u*)&Event, sizeof(MediaInfo_Event_DvDif_Analysis_Frame_0));
         #endif //MEDIAINFO_EVENTS
     }
 
