@@ -1,21 +1,8 @@
-// File_Hls - Info for HLS files
-// Copyright (C) 2010-2012 MediaArea.net SARL, Info@MediaArea.net
-//
-// This library is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Library General Public License as published by
-// the Free Software Foundation, either version 2 of the License, or
-// any later version.
-//
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public License
-// along with this library. If not, see <http://www.gnu.org/licenses/>.
-//
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+/*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
+ *
+ *  Use of this source code is governed by a BSD-style license that can
+ *  be found in the License.html file in the root of the source tree.
+ */
 
 //---------------------------------------------------------------------------
 // Pre-compilation
@@ -150,6 +137,8 @@ bool File_Hls::FileHeader_Begin()
     Fill(Stream_General, 0, General_Format, "HLS");
 
     ReferenceFiles=new File__ReferenceFilesHelper(this, Config);
+    if (!IsSub)
+        ReferenceFiles->ContainerHasNoId=true;
 
     File__ReferenceFilesHelper::reference ReferenceFile;
 
@@ -188,6 +177,8 @@ bool File_Hls::FileHeader_Begin()
         ReferenceFiles->TestContinuousFileNames=true;
     }
 
+    Element_Offset=File_Size;
+
     //All should be OK...
     return true;
 }
