@@ -1,20 +1,9 @@
-// File_Mk - Info for Matroska Video/Audio files
-// Copyright (C) 2002-2012 MediaArea.net SARL, Info@MediaArea.net
-//
-// This library is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Library General Public License as published by
-// the Free Software Foundation, either version 2 of the License, or
-// any later version.
-//
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public License
-// along with this library. If not, see <http://www.gnu.org/licenses/>.
-//
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+/*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
+ *
+ *  Use of this source code is governed by a BSD-style license that can
+ *  be found in the License.html file in the root of the source tree.
+ */
+
 //+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 //
 // Information about Matroska files
@@ -28,7 +17,6 @@
 
 //---------------------------------------------------------------------------
 #include "MediaInfo/File__Analyze.h"
-#include <map>
 //---------------------------------------------------------------------------
 
 namespace MediaInfoLib
@@ -278,7 +266,7 @@ private :
         ~stream()
         {
             delete Parser; //Parser=NULL;
-            delete ContentCompSettings_Buffer; //ContentCompSettings_Buffer=NULL;
+            delete[] ContentCompSettings_Buffer; //ContentCompSettings_Buffer=NULL;
         }
     };
     std::map<int64u, stream> Stream;
