@@ -1,21 +1,8 @@
-// File_Mpeg4 - Info for MPEG-4 files
-// Copyright (C) 2004-2012 MediaArea.net SARL, Info@MediaArea.net
-//
-// This library is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Library General Public License as published by
-// the Free Software Foundation, either version 2 of the License, or
-// any later version.
-//
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public License
-// along with this library. If not, see <http://www.gnu.org/licenses/>.
-//
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+/*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
+ *
+ *  Use of this source code is governed by a BSD-style license that can
+ *  be found in the License.html file in the root of the source tree.
+ */
 
 //---------------------------------------------------------------------------
 #ifndef MediaInfo_File_Mpeg4H
@@ -25,7 +12,6 @@
 //---------------------------------------------------------------------------
 #include "MediaInfo/File__Analyze.h"
 #include "MediaInfo/MediaInfo_Internal.h"
-#include <map>
 class File_MpegPs;
 //---------------------------------------------------------------------------
 
@@ -52,6 +38,7 @@ public :
 
 private :
     //Buffer - Global
+    void Read_Buffer_Init();
     void Read_Buffer_Unsynched();
     #if MEDIAINFO_SEEK
     size_t Read_Buffer_Seek (size_t Method, int64u Value, int64u ID);
@@ -64,6 +51,7 @@ private :
     bool BookMark_Needed();
 
     //Elements
+    void bloc();
     void cdat();
     void cdt2() {cdat();}
     void free();
@@ -87,6 +75,7 @@ private :
     void moof_traf_tfhd();
     void moof_traf_trun();
     void moov();
+    void moov_ainf();
     void moov_cmov();
     void moov_cmov_cmvd();
     void moov_cmov_cmvd_zlib();
@@ -135,6 +124,7 @@ private :
     void moov_trak_mdia_minf_gmhd_gmin();
     void moov_trak_mdia_minf_gmhd_tmcd();
     void moov_trak_mdia_minf_gmhd_tmcd_tcmi();
+    void moov_trak_mdia_minf_gmhd_tcmi();
     void moov_trak_mdia_minf_hint();
     void moov_trak_mdia_minf_hdlr();
     void moov_trak_mdia_minf_hmhd();
@@ -161,8 +151,11 @@ private :
     void moov_trak_mdia_minf_stbl_stsd_xxxxStream();
     void moov_trak_mdia_minf_stbl_stsd_xxxxText();
     void moov_trak_mdia_minf_stbl_stsd_xxxxVideo();
-    void moov_trak_mdia_minf_stbl_stsd_xxxx_avcC();
     void moov_trak_mdia_minf_stbl_stsd_xxxx_alac();
+    void moov_trak_mdia_minf_stbl_stsd_xxxx_ACLR();
+    void moov_trak_mdia_minf_stbl_stsd_xxxx_APRG();
+    void moov_trak_mdia_minf_stbl_stsd_xxxx_ARES();
+    void moov_trak_mdia_minf_stbl_stsd_xxxx_avcC();
     void moov_trak_mdia_minf_stbl_stsd_xxxx_bitr();
     void moov_trak_mdia_minf_stbl_stsd_xxxx_btrt();
     void moov_trak_mdia_minf_stbl_stsd_xxxx_chan();
@@ -170,12 +163,14 @@ private :
     void moov_trak_mdia_minf_stbl_stsd_xxxx_colr();
     void moov_trak_mdia_minf_stbl_stsd_xxxx_d263();
     void moov_trak_mdia_minf_stbl_stsd_xxxx_dac3();
+    void moov_trak_mdia_minf_stbl_stsd_xxxx_damr();
     void moov_trak_mdia_minf_stbl_stsd_xxxx_dec3();
     void moov_trak_mdia_minf_stbl_stsd_xxxx_ddts();
-    void moov_trak_mdia_minf_stbl_stsd_xxxx_damr();
+    void moov_trak_mdia_minf_stbl_stsd_xxxx_dvc1();
     void moov_trak_mdia_minf_stbl_stsd_xxxx_esds();
     void moov_trak_mdia_minf_stbl_stsd_xxxx_fiel();
     void moov_trak_mdia_minf_stbl_stsd_xxxx_glbl();
+    void moov_trak_mdia_minf_stbl_stsd_xxxx_hvcC();
     void moov_trak_mdia_minf_stbl_stsd_xxxx_idfm();
     void moov_trak_mdia_minf_stbl_stsd_xxxx_jp2h() {jp2h();}
     void moov_trak_mdia_minf_stbl_stsd_xxxx_jp2h_colr() {jp2h_colr();}
@@ -216,10 +211,16 @@ private :
     void moov_trak_tapt_enof();
     void moov_trak_tkhd();
     void moov_trak_tref();
+    void moov_trak_tref_chap();
+    void moov_trak_tref_clcp();
     void moov_trak_tref_dpnd();
+    void moov_trak_tref_fall();
+    void moov_trak_tref_folw();
+    void moov_trak_tref_forc();
     void moov_trak_tref_ipir();
     void moov_trak_tref_hint();
     void moov_trak_tref_mpod();
+    void moov_trak_tref_scpt();
     void moov_trak_tref_ssrc();
     void moov_trak_tref_sync();
     void moov_trak_tref_tmcd();
@@ -265,6 +266,7 @@ private :
     void moov_udta_XMP_();
     void moov_udta_yrrc();
     void moov_udta_xxxx();
+    void pdin();
     void PICT();
     void pckg();
     void pnot();
@@ -319,6 +321,7 @@ private :
     int64u                                  LastMdatPos; //This is the position of the byte after the last byte of mdat
     int64u                                  FirstMoovPos;
     int64u                                  moof_base_data_offset;
+    int64u                                  FrameCount_MaxPerStream;
     bool                                    data_offset_present;
     int64u                                  moof_traf_base_data_offset;
     int32u                                  moof_traf_default_sample_duration;
@@ -332,7 +335,7 @@ private :
     struct stream
     {
         Ztring                  File_Name;
-        File__Analyze*          Parser;
+        std::vector<File__Analyze*> Parsers;
         MediaInfo_Internal*     MI;
         struct timecode
         {
@@ -386,14 +389,18 @@ private :
         int32u                  mvex_trex_default_sample_size;
         int32u                  TimeCode_TrackID;
         bool                    TimeCode_IsVisual;
+        bool                    IsPcm;
         bool                    IsPcmMono;
         bool                    IsPriorityStream;
         bool                    IsFilled;
+        bool                    IsChapter;
+        bool                    ScanOrder_StoredDisplayedInverted;
         float32                 CleanAperture_Width;
         float32                 CleanAperture_Height;
         float32                 CleanAperture_PixelAspectRatio;
         #if MEDIAINFO_DEMUX || MEDIAINFO_SEEK
             int8u               Demux_Level;
+            int64u              Demux_Offset;
 
             struct stts_duration
             {
@@ -408,10 +415,13 @@ private :
             size_t          stts_Durations_Pos;
             int64u          stts_FramePos;
         #endif //MEDIAINFO_DEMUX || MEDIAINFO_SEEK
+        #if MEDIAINFO_DEMUX
+            bool            PtsDtsAreSame;
+            bool            Demux_EventWasSent;
+        #endif //MEDIAINFO_DEMUX
 
         stream()
         {
-            Parser=NULL;
             MI=NULL;
             TimeCode=NULL;
             StreamKind=Stream_Max;
@@ -433,22 +443,31 @@ private :
             mvex_trex_default_sample_size=0;
             TimeCode_TrackID=(int32u)-1;
             TimeCode_IsVisual=false;
+            IsPcm=false;
             IsPcmMono=false;
             IsPriorityStream=false;
             IsFilled=false;
+            IsChapter=false;
+            ScanOrder_StoredDisplayedInverted=false;
             CleanAperture_Width=0;
             CleanAperture_Height=0;
             CleanAperture_PixelAspectRatio=0;
             #if MEDIAINFO_DEMUX
                 Demux_Level=2; //Container
+                Demux_Offset=0;
                 stts_Durations_Pos=0;
                 stts_FramePos=0;
             #endif //MEDIAINFO_DEMUX
+            #if MEDIAINFO_DEMUX
+                PtsDtsAreSame=false;
+                Demux_EventWasSent=false;
+            #endif //MEDIAINFO_DEMUX
         }
 
         ~stream()
         {
-            delete Parser; //Parser=NULL;
+            for (size_t Pos=0; Pos<Parsers.size(); Pos++)
+                delete Parsers[Pos];
             delete MI; //MI=NULL;
             delete TimeCode; //TimeCode=NULL;
         }
@@ -456,7 +475,9 @@ private :
     typedef std::map<int32u, stream> streams;
     streams             Streams;
     streams::iterator   Stream;
-    File__ReferenceFilesHelper* ReferenceFiles;
+    #if defined(MEDIAINFO_REFERENCES_YES)
+        File__ReferenceFilesHelper* ReferenceFiles;
+    #endif //defined(MEDIAINFO_REFERENCES_YES)
     #if MEDIAINFO_NEXTPACKET
         bool                    ReferenceFiles_IsParsing;
     #endif //MEDIAINFO_NEXTPACKET
@@ -476,6 +497,7 @@ private :
     #if MEDIAINFO_DEMUX
         int64u          TimeCode_FrameOffset;
         int64u          TimeCode_DtsOffset;
+        std::map<int64u, int64u> StreamOffset_Jump; //Key is the current position, value is the jump position
     #endif //MEDIAINFO_DEMUX
 };
 
