@@ -291,6 +291,7 @@ File_Mpeg4_Descriptors::File_Mpeg4_Descriptors()
 
     //In
     KindOfStream=Stream_Max;
+    PosOfStream=(size_t)-1;
     Parser_DoNotFreeIt=false;
     SLConfig_DoNotFreeIt=false;
 
@@ -810,7 +811,9 @@ void File_Mpeg4_Descriptors::Descriptor_05()
                             {
                             std::string Data_Raw((const char*)(Buffer+Buffer_Offset), (size_t)Element_Size);
                             std::string Data_Base64(Base64::encode(Data_Raw));
-                            Parser->Fill(KindOfStream, 0, "Demux_InitBytes", Data_Base64);
+                            Parser->Fill(KindOfStream, PosOfStream, "Demux_InitBytes", Data_Base64);
+                            if (PosOfStream<(*Parser->Stream_More)[KindOfStream].size())
+                                (*Parser->Stream_More)[KindOfStream][PosOfStream](Ztring().From_Local("Demux_InitBytes"), Info_Options)=__T("N NT");
                             }
                             break;
                 default :   ;
