@@ -1,21 +1,8 @@
-// File_Mpeg4_TimeCode - Info for MPEG-4 TimeCode  files
-// Copyright (C) 2009-2012 MediaArea.net SARL, Info@MediaArea.net
-//
-// This library is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Library General Public License as published by
-// the Free Software Foundation, either version 2 of the License, or
-// any later version.
-//
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public License
-// along with this library. If not, see <http://www.gnu.org/licenses/>.
-//
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+/*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
+ *
+ *  Use of this source code is governed by a BSD-style license that can
+ *  be found in the License.html file in the root of the source tree.
+ */
 
 //---------------------------------------------------------------------------
 // Pre-compilation
@@ -35,6 +22,7 @@
 
 //---------------------------------------------------------------------------
 #include "MediaInfo/Multiple/File_Mpeg4_TimeCode.h"
+#include "MediaInfo/TimeCode.h"
 //---------------------------------------------------------------------------
 
 namespace MediaInfoLib
@@ -50,6 +38,10 @@ File_Mpeg4_TimeCode::File_Mpeg4_TimeCode()
 {
     //Out
     Pos=(int32u)-1;
+
+    NumberOfFrames=0;
+    DropFrame=false;
+    NegativeTimes=false;
 }
 
 //***************************************************************************
@@ -59,9 +51,25 @@ File_Mpeg4_TimeCode::File_Mpeg4_TimeCode()
 //---------------------------------------------------------------------------
 void File_Mpeg4_TimeCode::Streams_Fill()
 {
-    if (Pos!=(int32u)-1 && FrameRate)
+    if (Pos!=(int32u)-1 && NumberOfFrames)
     {
-        Fill(Stream_General, 0, "Delay", Pos*1000/FrameRate, 0);
+        int64s  Pos_Temp=Pos;
+        float64 FrameRate_WithDF=NumberOfFrames;
+        if (DropFrame)
+        {
+            float64 FramesPerHour_NDF=FrameRate_WithDF*60*60;
+            FrameRate_WithDF*=(FramesPerHour_NDF-108)/FramesPerHour_NDF;
+        }
+
+        Fill(Stream_General, 0, "Delay", Pos_Temp*1000/FrameRate_WithDF, 0);
+
+        TimeCode TC(Pos_Temp, NumberOfFrames, DropFrame);
+        Stream_Prepare(Stream_Other);
+        Fill(Stream_Other, StreamPos_Last, Other_Type, "Time code");
+        Fill(Stream_Other, StreamPos_Last, Other_TimeCode_FirstFrame, TC.ToString().c_str());
+        if (Frame_Count==1)
+            Fill(Stream_Other, StreamPos_Last, Other_TimeCode_Settings, "Striped");
+
     }
 }
 
@@ -86,6 +94,8 @@ void File_Mpeg4_TimeCode::Read_Buffer_Continue()
     }
 
     FILLING_BEGIN();
+        Frame_Count+=Element_Size/4;
+
         if (!Status[IsAccepted])
         {
             Accept("TimeCode");
