@@ -84,6 +84,9 @@ public :
     #if MEDIAINFO_SEEK
         int64u Unsynch_Frame_Count_Temp;
     #endif //MEDIAINFO_SEEK
+    #if defined(MEDIAINFO_ARIBSTDB24B37_YES)
+        bool FromAribStdB24B37;
+    #endif //defined(MEDIAINFO_ARIBSTDB24B37_YES)
 
     //Out
     bool   HasTimeStamps;
@@ -95,6 +98,7 @@ public :
 private :
     //Streams management
     void Streams_Fill();
+    void Streams_Update();
     void Streams_Finish();
 
     //Buffer - File header
