@@ -43,6 +43,9 @@ public :
     #ifdef MEDIAINFO_TSP_YES
         size_t TSP_Size;
     #endif
+    #ifdef MEDIAINFO_ARIBSTDB24B37_YES
+        bool FromAribStdB24B37;
+    #endif
 
     //Constructor/Destructor
     File_MpegTs();
@@ -127,6 +130,7 @@ private :
     #endif // MEDIAINFO_ADVANCED
     #endif //MEDIAINFO_MPEGTS_PCR_YES
     void Streams_Update_Duration_End();
+    void SetAllToPES();
 
     #if MEDIAINFO_DUPLICATE
         //File__Duplicate
