@@ -1,20 +1,9 @@
-// File_Mpeg_Descriptors - Info for MPEG files
-// Copyright (C) 2007-2012 MediaArea.net SARL, Info@MediaArea.net
-//
-// This library is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Library General Public License as published by
-// the Free Software Foundation, either version 2 of the License, or
-// any later version.
-//
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public License
-// along with this library. If not, see <http://www.gnu.org/licenses/>.
-//
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+/*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
+ *
+ *  Use of this source code is governed by a BSD-style license that can
+ *  be found in the License.html file in the root of the source tree.
+ */
+
 //+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 //
 // Information about MPEG files, Descriptors
@@ -27,10 +16,9 @@
 //---------------------------------------------------------------------------
 
 //---------------------------------------------------------------------------
-#include "MediaInfo/File__Analyze.h"
 #include "MediaInfo/Multiple/File_Mpeg4_Descriptors.h"
 #include "MediaInfo/Duplicate/File__Duplicate_MpegTs.h"
-#include <map>
+#include <cfloat>
 //---------------------------------------------------------------------------
 
 namespace MediaInfoLib
@@ -60,7 +48,10 @@ struct complete_stream
         struct program
         {
             bool HasChanged;
+            std::map<int8u, string> Eia708_Languages; //Sometimes, it is in program descriptors instead of inside the video stream descriptors //Key is caption_service_number
             std::map<std::string, Ztring> Infos;
+            std::map<std::string, Ztring> ExtraInfos_Content;
+            std::map<std::string, Ztring> ExtraInfos_Option;
             std::map<Ztring, Ztring> EPGs;
             std::vector<int16u> elementary_PIDs;
             size_t StreamPos; //Stream_Menu
@@ -71,10 +62,12 @@ struct complete_stream
             bool   source_id_IsValid;
             bool   IsParsed;
             bool   IsRegistered;
+            bool   HasNotDisplayableStreams; //e.g. unknown stream, KLV, SCTE 35
             bool   Update_Needed_IsRegistered;
             bool   Update_Needed_StreamCount;
             bool   Update_Needed_StreamPos;
             bool   Update_Needed_Info;
+            bool   Eia608_IsPresent;
 
             //DVB
             struct dvb_epg_block
@@ -143,16 +136,19 @@ struct complete_stream
                 source_id_IsValid=false;
                 IsParsed=false;
                 IsRegistered=false;
+                HasNotDisplayableStreams=false;
                 Update_Needed_IsRegistered=false;
                 Update_Needed_StreamCount=false;
                 Update_Needed_StreamPos=false;
                 Update_Needed_Info=false;
                 DVB_EPG_Blocks_IsUpdated=false;
+                Eia608_IsPresent=false;
                 Scte35=NULL;
             }
         };
         typedef std::map<int16u, program> programs; //Key is program_number
         programs Programs; //Key is program_number
+        std::vector<int16u> programs_List;
         size_t   Programs_NotParsedCount;
 
         //Per IOD
@@ -232,7 +228,8 @@ struct complete_stream
         typedef std::vector<table_id*>              table_ids;
         table_ids                                   Table_IDs; //Key is table_id
         std::map<std::string, Ztring>               Infos;
-        std::map<int8u, Ztring>                     Languages; //Key is caption_service_number or 128+line21_field
+        std::map<std::string, Ztring>               Infos_Option;
+        std::map<int8u, string>                     Eia708_Languages; //Key is caption_service_number
         struct teletext
         {
             std::map<std::string, Ztring>           Infos;
@@ -255,6 +252,21 @@ struct complete_stream
             int64u                                  TimeStamp_End_Offset;
             int16u                                  PCR_PID; //If this pid has no PCR, decide which PCR should be used
             bool                                    TimeStamp_End_IsUpdated;
+            float64                                 TimeStamp_InstantaneousBitRate_Current_Min;
+            float64                                 TimeStamp_InstantaneousBitRate_Current_Raw;
+            float64                                 TimeStamp_InstantaneousBitRate_Current_Max;
+            int64u                                  TimeStamp_InstantaneousBitRate_BitRateMode_IsCbr;
+            int64u                                  TimeStamp_InstantaneousBitRate_BitRateMode_IsVbr;
+            #if MEDIAINFO_ADVANCED
+                float64                             TimeStamp_InstantaneousBitRate_Min_Raw;
+                float64                             TimeStamp_InstantaneousBitRate_Max_Raw;
+                int64u                              TimeStamp_Distance_Min;
+                int64u                              TimeStamp_Distance_Max;
+                int64u                              TimeStamp_Distance_Total;
+                int64u                              TimeStamp_Distance_Count;
+                int64u                              TimeStamp_HasProblems;
+                std::vector<int64u>                 TimeStamp_Intermediate;
+            #endif // MEDIAINFO_ADVANCED
         #endif //MEDIAINFO_MPEGTS_PCR_YES
         int32u                                      registration_format_identifier;
         int16u                                      FMC_ES_ID;
@@ -278,7 +290,10 @@ struct complete_stream
         bool                                        IsRegistered;
         bool                                        IsUpdated_IsRegistered;
         bool                                        IsUpdated_Info;
+        bool                                        CA_system_ID_MustSkipSlices;
+        bool                                        Eia608_IsPresent;
         size_t                                      IsScrambled;
+        int16u                                      CA_system_ID;
         int16u                                      SubStream_pid;
         #if MEDIAINFO_IBI
             int64u                                  Ibi_SynchronizationOffset_BeginOfFrame;
@@ -302,6 +317,20 @@ struct complete_stream
                 TimeStamp_End_Offset=(int64u)-1;
                 PCR_PID=0x0000;
                 TimeStamp_End_IsUpdated=false;
+                TimeStamp_InstantaneousBitRate_Current_Min=0;
+                TimeStamp_InstantaneousBitRate_Current_Raw=0;
+                TimeStamp_InstantaneousBitRate_Current_Max=0;
+                TimeStamp_InstantaneousBitRate_BitRateMode_IsCbr=0;
+                TimeStamp_InstantaneousBitRate_BitRateMode_IsVbr=0;
+                #if MEDIAINFO_ADVANCED
+                    TimeStamp_InstantaneousBitRate_Min_Raw=DBL_MAX;
+                    TimeStamp_InstantaneousBitRate_Max_Raw=0;
+                    TimeStamp_Distance_Min=(int64u)-1;
+                    TimeStamp_Distance_Max=0;
+                    TimeStamp_Distance_Total=0;
+                    TimeStamp_Distance_Count=0;
+                    TimeStamp_HasProblems=0;
+                #endif // MEDIAINFO_ADVANCED
             #endif //MEDIAINFO_MPEGTS_PCR_YES
             registration_format_identifier=0x00000000;
             FMC_ES_ID=0x0000;
@@ -326,6 +355,9 @@ struct complete_stream
             IsUpdated_IsRegistered=false;
             IsUpdated_Info=false;
             IsScrambled=false;
+            CA_system_ID_MustSkipSlices=false;
+            CA_system_ID=0x0000;
+            Eia608_IsPresent=false;
             SubStream_pid=0x0000;
             #if MEDIAINFO_IBI
                 Ibi_SynchronizationOffset_BeginOfFrame=(int64u)-1;
@@ -407,12 +439,14 @@ struct complete_stream
                 int32u  start_time;
                 Ztring  duration;
                 Ztring  title;
-                std::map<int8u, Ztring>  Languages; //Key is caption_service_number or 128+line21_field
+                std::map<int8u, string>  Eia708_Languages; //Key is caption_service_number
                 std::map<int16u, Ztring> texts;
+                bool                     Eia608_IsPresent;
 
                 event()
                 {
                     start_time=(int32u)-1;
+                    Eia608_IsPresent=false;
                 }
             };
 
@@ -478,7 +512,7 @@ struct complete_stream
         while (Duplicates_Temp!=Duplicates.end())
         {
             delete Duplicates_Temp->second; //Duplicates_Temp->second=NULL
-            Duplicates_Temp++;
+            ++Duplicates_Temp;
         }
     }
 };
@@ -513,6 +547,9 @@ public :
     File_Mpeg_Descriptors();
 
 private :
+    //Buffer - File header
+    void FileHeader_Parse();
+
     //Buffer - Per element
     void Header_Parse();
     void Data_Parse();
@@ -568,6 +605,18 @@ private :
     void Descriptor_2D() {Skip_XX(Element_Size, "Data");};
     void Descriptor_2E() {Skip_XX(Element_Size, "Data");};
     void Descriptor_2F();
+    void Descriptor_30() {Skip_XX(Element_Size, "Data");};
+    void Descriptor_31() {Skip_XX(Element_Size, "Data");};
+    void Descriptor_32() {Skip_XX(Element_Size, "Data");};
+    void Descriptor_33() {Skip_XX(Element_Size, "Data");};
+    void Descriptor_34() {Skip_XX(Element_Size, "Data");};
+    void Descriptor_35() {Skip_XX(Element_Size, "Data");};
+    void Descriptor_36() {Skip_XX(Element_Size, "Data");};
+    void Descriptor_37() {Skip_XX(Element_Size, "Data");};
+    void Descriptor_38() {Skip_XX(Element_Size, "Data");};
+    void Descriptor_39() {Skip_XX(Element_Size, "Data");};
+    void Descriptor_3A() {Skip_XX(Element_Size, "Data");};
+    void Descriptor_3F() {Skip_XX(Element_Size, "Data");};
     void Descriptor_40();
     void Descriptor_41();
     void Descriptor_42() {Skip_XX(Element_Size, "Data");};
@@ -644,6 +693,11 @@ private :
     void Descriptor_A9() {Skip_XX(Element_Size, "Data");};
     void Descriptor_AA();
     void Descriptor_AB() {Skip_XX(Element_Size, "Data");};
+    void Descriptor_C1();
+    void Descriptor_C8();
+    void Descriptor_DE();
+    void Descriptor_FC();
+    void Descriptor_FD();
 
     //SCTE 35
     void CUEI_00();
