@@ -1,21 +1,8 @@
-// File_Ogg_SubElement - Info for OGG files
-// Copyright (C) 2007-2012 MediaArea.net SARL, Info@MediaArea.net
-//
-// This library is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Library General Public License as published by
-// the Free Software Foundation, either version 2 of the License, or
-// any later version.
-//
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public License
-// along with this library. If not, see <http://www.gnu.org/licenses/>.
-//
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+/*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
+ *
+ *  Use of this source code is governed by a BSD-style license that can
+ *  be found in the License.html file in the root of the source tree.
+ */
 
 //---------------------------------------------------------------------------
 // Pre-compilation
@@ -272,10 +259,10 @@ bool File_Ogg_SubElement::Header_Begin()
 void File_Ogg_SubElement::Header_Parse()
 {
     //Parsing
-    int8u  Type;
-    bool lenbytes0, lenbytes1, lenbytes2;
+    int8u Type;
     if (Identified && WithType)
     {
+        bool lenbytes0, lenbytes1, lenbytes2;
         Get_L1 (Type,                                               "Type");
             Skip_Flags(Type, 0,                                     "Indicates data packet");
             Get_Flags (Type, 1, lenbytes2,                          "Bit 2 of lenbytes");
@@ -543,6 +530,7 @@ void File_Ogg_SubElement::Identification_OpusHead()
         Fill(Stream_Audio, 0, Audio_Codec, "Opus");
     #endif
     WithType=false;
+    absolute_granule_position_Resolution=48000; // From specs: "It is possible to run a decoder at other sampling rates, but the format and this specification always count samples assuming a 48 kHz decoding rate."
 }
 
 //---------------------------------------------------------------------------
