@@ -1,21 +1,8 @@
-// File_Rm - Info for Real Media files
-// Copyright (C) 2002-2012 MediaArea.net SARL, Info@MediaArea.net
-//
-// This library is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Library General Public License as published by
-// the Free Software Foundation, either version 2 of the License, or
-// any later version.
-//
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public License
-// along with this library. If not, see <http://www.gnu.org/licenses/>.
-//
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+/*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
+ *
+ *  Use of this source code is governed by a BSD-style license that can
+ *  be found in the License.html file in the root of the source tree.
+ */
 
 //---------------------------------------------------------------------------
 // Pre-compilation
@@ -379,10 +366,10 @@ void File_Rm::MDPR()
         MDPR_IsStream=false; //What do we with this?
     else if (mime_type=="logical-fileinfo")
         MDPR_fileinfo();
-    else if (mime_type=="logical-video/x-pn-multirate-realvideo")
-        MDPR_IsStream=false; //What do we with this?
-    else if (mime_type.find("logical-video/")==0)
-        MDPR_IsStream=false; //What do we with this?
+    //else if (mime_type=="logical-video/x-pn-multirate-realvideo")
+    //    MDPR_IsStream=false; //What do we with this?
+    //else if (mime_type.find("logical-video/")==0)
+    //    MDPR_IsStream=false; //What do we with this?
     else
         MDPR_IsStream=false;
 
@@ -392,8 +379,8 @@ void File_Rm::MDPR()
         {
             Fill(StreamKind_Last, StreamPos_Last, General_ID, stream_number);
             Fill(StreamKind_Last, StreamPos_Last, Fill_Parameter(StreamKind_Last, Generic_BitRate), avg_bit_rate, 10, true);
-            Fill(StreamKind_Last, StreamPos_Last, Fill_Parameter(StreamKind_Last, Generic_Delay), start_time);
-            Fill(StreamKind_Last, StreamPos_Last, Fill_Parameter(StreamKind_Last, Generic_Delay_Source), "Container");
+            //Fill(StreamKind_Last, StreamPos_Last, Fill_Parameter(StreamKind_Last, Generic_Delay), start_time);
+            //Fill(StreamKind_Last, StreamPos_Last, Fill_Parameter(StreamKind_Last, Generic_Delay_Source), "Container");
             Fill(StreamKind_Last, StreamPos_Last, Fill_Parameter(StreamKind_Last, Generic_Duration), duration);
         }
     FILLING_END();
