@@ -11,6 +11,7 @@
 
 //---------------------------------------------------------------------------
 #include "MediaInfo/File__Analyze.h"
+#include "MediaInfo/MediaInfo_Internal.h"
 #include <vector>
 //---------------------------------------------------------------------------
 
@@ -44,14 +45,39 @@ public :
         size_t              State;
         std::map<std::string, Ztring> Infos;
         MediaInfo_Internal* MI;
+        struct completeduration
+        {
+            Ztring FileName;
+            MediaInfo_Internal* MI;
+            #if MEDIAINFO_DEMUX
+                int64u Demux_Offset_Frame;
+                int64u Demux_Offset_DTS;
+                int64u Demux_Offset_FileSize;
+            #endif //MEDIAINFO_DEMUX
+
+            completeduration()
+            {
+                MI=NULL;
+                #if MEDIAINFO_DEMUX
+                    Demux_Offset_Frame=0;
+                    Demux_Offset_DTS=0;
+                    Demux_Offset_FileSize=0;
+                #endif //MEDIAINFO_DEMUX
+            }
+
+            ~completeduration()
+            {
+                delete MI;
+            }
+        };
+        vector<completeduration*>   CompleteDuration;
+        size_t                      CompleteDuration_Pos;
         #if MEDIAINFO_FILTER
             int64u          Enabled;
         #endif //MEDIAINFO_FILTER
-        #if MEDIAINFO_NEXTPACKET
-            std::bitset<32> Status;
-            #if MEDIAINFO_IBI
-                ibi::stream IbiStream;
-            #endif //MEDIAINFO_IBI
+        std::bitset<32> Status;
+        #if MEDIAINFO_NEXTPACKET && MEDIAINFO_IBI
+            ibi::stream IbiStream;
         #endif //MEDIAINFO_NEXTPACKET && MEDIAINFO_IBI
 
         reference()
@@ -71,19 +97,29 @@ public :
             #endif //MEDIAINFO_ADVANCED || MEDIAINFO_MD5
             State=0;
             MI=NULL;
+            CompleteDuration_Pos=0;
             #if MEDIAINFO_FILTER
                 Enabled=true;
             #endif //MEDIAINFO_FILTER
         }
+
+        ~reference()
+        {
+            for (size_t Pos=0; Pos<CompleteDuration.size(); Pos++)
+                delete CompleteDuration[Pos]; //CompleteDuration[Pos]=NULL;
+        }
     };
     typedef std::vector<reference>  references;
     references                      References;
     bool                            TestContinuousFileNames;
+    bool                            FilesForStorage;
     bool                            ContainerHasNoId;
     bool                            HasMainFile;
+    bool                            HasMainFile_Filled;
     int64u                          ID_Max;
 
     //Streams management
+    bool ParseReference_Init();
     void ParseReferences();
 
     //Constructor / Destructor
@@ -124,6 +160,7 @@ private :
     //Helpers
     size_t Stream_Prepare(stream_t StreamKind, size_t StreamPos=(size_t)-1);
     void   FileSize_Compute();
+    MediaInfo_Internal* MI_Create();
     #if MEDIAINFO_ADVANCED || MEDIAINFO_MD5
         void   List_Compute();
     #endif //MEDIAINFO_ADVANCED || MEDIAINFO_MD5
@@ -131,9 +168,11 @@ private :
     void SubFile_Start();
     int64u                          StreamID_Previous;
     #endif //MEDIAINFO_EVENTS
+    #if MEDIAINFO_DEMUX
+        int64u                      Offset_Video_DTS;
+    #endif //MEDIAINFO_DEMUX
 };
 
 } //NameSpace
 
 #endif
-
