@@ -19,6 +19,9 @@
 #include "MediaInfo/File__Analyze.h"
 //---------------------------------------------------------------------------
 
+class tinyxml2::XMLDocument;
+class tinyxml2::XMLElement;
+
 namespace MediaInfoLib
 {
 
@@ -28,12 +31,26 @@ namespace MediaInfoLib
 
 class File_Ttml : public File__Analyze
 {
+public :
+    File_Ttml();
+    ~File_Ttml();
+
 private :
     //Buffer - File header
     bool FileHeader_Begin();
+
+    //Buffer - Global
+    #if MEDIAINFO_SEEK
+    size_t Read_Buffer_Seek (size_t Method, int64u Value, int64u ID);
+    #endif //MEDIAINFO_SEEK
+    void Read_Buffer_Continue();
+
+    //Temp
+    tinyxml2::XMLDocument*      document;
+    tinyxml2::XMLElement*       div;
+    tinyxml2::XMLElement*       p;
 };
 
 } //NameSpace
 
 #endif
-
