@@ -1,20 +1,9 @@
-// File__Duplicate - Duplication of some formats
-// Copyright (C) 2007-2012 MediaArea.net SARL, Info@MediaArea.net
-//
-// This library is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Library General Public License as published by
-// the Free Software Foundation, either version 2 of the License, or
-// any later version.
-//
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public License
-// along with this library. If not, see <http://www.gnu.org/licenses/>.
-//
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+/*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
+ *
+ *  Use of this source code is governed by a BSD-style license that can
+ *  be found in the License.html file in the root of the source tree.
+ */
+
 //+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 //
 // Duplication helper for some specific formats
@@ -84,7 +73,7 @@ bool File_Avc::File__Duplicate_Set (const Ztring &Value)
     std::vector<ZtringList::iterator> Targets_ToRemove;
     std::vector<ZtringList::iterator> Orders_ToAdd;
     std::vector<ZtringList::iterator> Orders_ToRemove;
-    for (ZtringList::iterator Current=List.begin(); Current<List.end(); Current++)
+    for (ZtringList::iterator Current=List.begin(); Current<List.end(); ++Current)
     {
         //Detecting if we want to remove
         bool ToRemove=false;
@@ -117,11 +106,11 @@ bool File_Avc::File__Duplicate_Set (const Ztring &Value)
     FLV=false;
 
     //For each target to add
-    for (std::vector<ZtringList::iterator>::iterator Target=Targets_ToAdd.begin(); Target<Targets_ToAdd.end(); Target++)
+    for (std::vector<ZtringList::iterator>::iterator Target=Targets_ToAdd.begin(); Target<Targets_ToAdd.end(); ++Target)
         Writer.Configure(**Target);
 
     //For each order to add
-    for (std::vector<ZtringList::iterator>::iterator Order=Orders_ToAdd.begin(); Order<Orders_ToAdd.end(); Order++)
+    for (std::vector<ZtringList::iterator>::iterator Order=Orders_ToAdd.begin(); Order<Orders_ToAdd.end(); ++Order)
         if ((**Order)==__T("format=Flv"))
             FLV=true;
 
