@@ -1,21 +1,8 @@
-// File_AvsV - Info for AVS Video files
-// Copyright (C) 2006-2012 MediaArea.net SARL, Info@MediaArea.net
-//
-// This library is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Library General Public License as published by
-// the Free Software Foundation, either version 2 of the License, or
-// any later version.
-//
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public License
-// along with this library. If not, see <http://www.gnu.org/licenses/>.
-//
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+/*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
+ *
+ *  Use of this source code is governed by a BSD-style license that can
+ *  be found in the License.html file in the root of the source tree.
+ */
 
 //---------------------------------------------------------------------------
 // Pre-compilation
@@ -363,7 +350,10 @@ bool File_AvsV::Header_Parser_QuickSearch()
         Buffer_Offset+=4;
         Synched=false;
         if (!Synchronize_0x000001())
+        {
+            UnSynched_IsNotJunk=true;
             return false;
+        }
     }
 
     if (Buffer_Offset+3==Buffer_Size)
@@ -419,8 +409,8 @@ void File_AvsV::Data_Parse()
         case 0xB4:
         case 0xB8: reserved(); break;
         default:
-            if (Element_Code>=0x00
-             && Element_Code<=0xAF) slice();
+            if (Element_Code>=0x00 && Element_Code<=0xAF)
+                slice();
             else
             {
                 if (Frame_Count==0 && Buffer_TotalBytes>Buffer_TotalBytes_FirstSynched_Max)
@@ -586,7 +576,7 @@ void File_AvsV::extension_start()
     Get_S1 ( 4, extension_start_code_identifier,                "extension_start_code_identifier"); Param_Info1(AvsV_extension_start_code_identifier[extension_start_code_identifier]);
     Element_Info1(AvsV_extension_start_code_identifier[extension_start_code_identifier]);
 
-         switch (extension_start_code_identifier)
+    switch (extension_start_code_identifier)
     {
         case 2  :{ //sequence_display
                     //Parsing
@@ -667,7 +657,6 @@ void File_AvsV::extension_start()
                     BS_End();
                     Skip_XX(Element_Size-Element_Offset,        "data");
                 }
-
     }
 
     //Not sure, but the 3 first official files have this
