@@ -253,6 +253,16 @@ File_Vc1::~File_Vc1()
 // Streams management
 //***************************************************************************
 
+//---------------------------------------------------------------------------
+void File_Vc1::Streams_Accept()
+{
+    //Filling
+    Stream_Prepare(Stream_Video);
+    Fill(Stream_Video, 0, Video_Format, "VC-1");
+    Fill(Stream_Video, 0, Video_Codec, From_WMV3?"WMV3":"VC-1"); //For compatibility with the old reaction
+    Fill(Stream_Video, 0, Video_BitDepth, 8);
+}
+
 //---------------------------------------------------------------------------
 void File_Vc1::Streams_Fill()
 {
@@ -265,12 +275,6 @@ void File_Vc1::Streams_Fill()
     else
         PixelAspectRatio=1; //Unknown
 
-    //Filling
-    Stream_Prepare(Stream_Video);
-    Fill(Stream_Video, 0, Video_Format, "VC-1");
-    Fill(Stream_Video, 0, Video_Codec, From_WMV3?"WMV3":"VC-1"); //For compatibility with the old reaction
-    Fill(Stream_Video, 0, Video_BitDepth, 8);
-
     Ztring Profile;
     if (profile!=(int8u)-1)
         Profile=Vc1_Profile[profile];
@@ -507,7 +511,9 @@ bool File_Vc1::Demux_UnpacketizeContainer_Test()
                         case 0x0D :
                         case 0x0F :
                                     MustBreak=true; break;
-                        default   : MustBreak=false;
+                        default   :
+                                    Demux_Offset+=3;
+                                    MustBreak=false;
                     }
                     if (MustBreak)
                         break; //while() loop
@@ -553,6 +559,7 @@ bool File_Vc1::Demux_UnpacketizeContainer_Test()
                                 std::string Data_Raw((const char*)(Buffer+Buffer_Offset), (size_t)(Header_End-Buffer_Offset));
                                 std::string Data_Base64(Base64::encode(Data_Raw));
                                 Fill(Stream_Video, StreamPos_Last, "Demux_InitBytes", Data_Base64);
+                                (*Stream_More)[Stream_Video][StreamPos_Last](Ztring().From_Local("Demux_InitBytes"), Info_Options)=__T("N NT");
                                 }
                                 break;
                     default :   ;
@@ -1025,6 +1032,7 @@ void File_Vc1::EntryPointHeader()
                                 std::string Data_Raw((char*)InitData_Buffer_Temp, InitData_Buffer_Temp_Size);
                                 std::string Data_Base64(Base64::encode(Data_Raw));
                                 Fill(Stream_Video, StreamPos_Last, "Demux_InitBytes", Data_Base64);
+                                (*Stream_More)[Stream_Video][StreamPos_Last](Ztring().From_Local("Demux_InitBytes"), Info_Options)=__T("N NT");
                                 }
                                 break;
                     default :   ;
