@@ -448,9 +448,6 @@ void*           __stdcall MediaInfo_New ()
     {
         MI_Handle[NULL]=new MI_List; //Generic Handle
         MI_Handle[NULL]->Ansi.clear();
-
-        //Localisation
-        setlocale(LC_ALL, """""");
     }
     v07Mode=true; //Application is compatible with v0.7+ interface
 
@@ -632,9 +629,6 @@ const wchar_t*     __stdcall MediaInfo_Option (void* Handle, const wchar_t* Opti
     {
         MI_Handle[NULL]=new MI_List; //Generic Handle
         MI_Handle[NULL]->Ansi.clear();
-
-        //Localisation
-        setlocale(LC_ALL, """""");
     }
 
     //DLL only option
@@ -647,6 +641,11 @@ const wchar_t*     __stdcall MediaInfo_Option (void* Handle, const wchar_t* Opti
         MI_Handle[NULL]->Unicode=L"OK";
         return MI_Handle[NULL]->Unicode.c_str();
     }
+    if (ZenLib::Ztring(Option).Compare(L"setlocale_LC_CTYPE", L"=="))
+    {
+        setlocale(LC_CTYPE, utf8?ZenLib::Ztring(Value).To_UTF8().c_str():ZenLib::Ztring(Value).To_Local().c_str());
+        return MI_Handle[NULL]->Unicode.c_str();
+    }
 
     if (Handle)
     {
@@ -692,9 +691,6 @@ void*           __stdcall MediaInfoList_New ()
     {
         MI_Handle[NULL]=new MI_List; //Generic Handle
         MI_Handle[NULL]->Ansi.clear();
-
-        //Localisation
-        setlocale(LC_ALL, """""");
     }
     v07Mode=true; //Application is compatible with v0.7+ interface
 
@@ -830,9 +826,6 @@ const wchar_t*     __stdcall MediaInfoList_Option (void* Handle, const wchar_t*
     {
         MI_Handle[NULL]=new MI_List; //Generic Handle
         MI_Handle[NULL]->Ansi.clear();
-
-        //Localisation
-        setlocale(LC_ALL, """""");
     }
 
     //DLL only option
@@ -845,6 +838,11 @@ const wchar_t*     __stdcall MediaInfoList_Option (void* Handle, const wchar_t*
         MI_Handle[NULL]->Unicode=L"OK";
         return MI_Handle[NULL]->Unicode.c_str();
     }
+    if (ZenLib::Ztring(Option).Compare(L"setlocale_LC_CTYPE", L"=="))
+    {
+        setlocale(LC_CTYPE, utf8?ZenLib::Ztring(Value).To_UTF8().c_str():ZenLib::Ztring(Value).To_Local().c_str());
+        return MI_Handle[NULL]->Unicode.c_str();
+    }
 
     if (Handle)
     {
