@@ -1,32 +1,20 @@
-## MediaInfoDLL - All info about media files, for DLL
-#  Copyright (C) 2007-2009 Jerome Martinez, Zen@MediaArea.net
-#
-#  This library is free software: you can redistribute it and/or modify it
-#  under the terms of the GNU Lesser General Public License as published by
-#  the Free Software Foundation, either version 3 of the License, or
-#  any later version.
-#
-#  This library is distributed in the hope that it will be useful,
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#  GNU Lesser General Public License for more details.
-#
-#  You should have received a copy of the GNU Lesser General Public License
-#  along with this library. If not, see <http://www.gnu.org/licenses/>.
-#
-# +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+## Copyright (c) MediaArea.net SARL. All Rights Reserved.
+ #
+ # Use of this source code is governed by a BSD-style license that can
+ # be found in the License.html file in the root of the source tree.
+ ##
+
 # +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 #
 #  Public DLL interface implementation
 #  Wrapper for MediaInfo Library
 #  Please see MediaInfo.h for help
 #
-# +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
-#
 # Converted to python module by Petr Kaderabek
 # Modifications by Jerome Martinez
+# Python 3 update by Jerome Martinez
 #
-
+# +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
 
 import os
 from ctypes import *
@@ -50,7 +38,7 @@ else:
 
 
 class Stream:
-    General, Video, Audio, Text, Chapters, Image, Menu, Max = range(8)
+    General, Video, Audio, Text, Other, Image, Menu, Max = range(8)
 
 class Info:
     Name, Text, Measure, Options, Name_Text, Measure_Text, Info, HowTo, Max = range(9)
@@ -262,7 +250,12 @@ class MediaInfo:
     def State_Get(self):
         return self.MediaInfo_State_Get(self.Handle)
     def Count_Get(self, StreamKind, StreamNumber=-1):
-        return self.MediaInfo_Count_Get(self.Handle, StreamKind, StreamNumber)
+        if StreamNumber == -1:
+                #We should use -1 the same way, but it fails on 64-bit
+                #so we use slower Get() with a character string
+                return int(self.Get(StreamKind, 0, "StreamCount"))
+        else:
+                return self.MediaInfo_Count_Get(self.Handle, StreamKind, StreamNumber)
 
 
 class MediaInfoList:
@@ -364,39 +357,38 @@ class MediaInfoList:
 
     #Handling
     def __init__(self):
-        self.Handle=MediaInfoList_New()
+        self.Handle = self.MediaInfoList_New()
     def __del__(self):
-        MediaInfoList_Delete(self.Handle)
+        self.MediaInfoList_Delete(self.Handle)
     def Open(self, Files, Options=FileOptions.Nothing):
-        return MediaInfoList_Open(self.Handle, Files, Options)
+        return self.MediaInfoList_Open(self.Handle, Files, Options)
     def Open_Buffer(self, Begin, Begin_Size, End=None, End_Size=0):
-        return MediaInfoList_Open_Buffer (self.Handle, Begin, Begin_Size, End, End_Size)
+        return self.MediaInfoList_Open_Buffer (self.Handle, Begin, Begin_Size, End, End_Size)
     def Save(self, FilePos):
-        return MediaInfoList_Save(self.Handle, FilePos)
+        return self.MediaInfoList_Save(self.Handle, FilePos)
     def Close(self, FilePos):
-        MediaInfoList_Close (self.Handle, FilePos)
+        self.MediaInfoList_Close (self.Handle, FilePos)
 
     #General information
     def Inform(self, FilePos, Reserved=0):
-        return MediaInfoList_Inform (self.Handle, FilePos, Reserved)
+        return self.MediaInfoList_Inform (self.Handle, FilePos, Reserved)
     def GetI(self, FilePos, StreamKind, StreamNumber, Parameter, InfoKind=Info.Text):
-        return MediaInfoList_GetI (self.Handle, FilePos, StreamKind, StreamNumber, Parameter, InfoKind)
+        return self.MediaInfoList_GetI (self.Handle, FilePos, StreamKind, StreamNumber, Parameter, InfoKind)
     def Get(self, FilePos, StreamKind, StreamNumber, Parameter, InfoKind=Info.Text, SearchKind=Info.Name):
-        return MediaInfoList_Get (self.Handle, FilePos, StreamKind, StreamNumber, (Parameter), InfoKind, SearchKind)
+        return self.MediaInfoList_Get (self.Handle, FilePos, StreamKind, StreamNumber, (Parameter), InfoKind, SearchKind)
     def SetI(self, ToSet, FilePos, StreamKind, StreamNumber, Parameter, OldParameter=u""):
-        return MediaInfoList_SetI (self, Handle, ToSet, FilePos, StreamKind, StreamNumber, Parameter, OldParameter)
+        return self.MediaInfoList_SetI (self, Handle, ToSet, FilePos, StreamKind, StreamNumber, Parameter, OldParameter)
     def Set(self, ToSet, FilePos, StreamKind, StreamNumber, Parameter, OldParameter=u""):
-        return MediaInfoList_Set (self.Handle, ToSet, FilePos, StreamKind, StreamNumber, Parameter, OldParameter)
+        return self.MediaInfoList_Set (self.Handle, ToSet, FilePos, StreamKind, StreamNumber, Parameter, OldParameter)
 
     #Options
     def Option(self, Option, Value=u""):
-        return MediaInfoList_Option (self.Handle, Option, Value)
+        return self.MediaInfoList_Option (self.Handle, Option, Value)
     def Option_Static(self, Option, Value=u""):
-        return MediaInfoList_Option(None, Option, Value)
+        return self.MediaInfoList_Option(None, Option, Value)
     def State_Get(self):
-        return MediaInfoList_State_Get (self.Handle)
+        return self.MediaInfoList_State_Get (self.Handle)
     def Count_Get(self, FilePos, StreamKind, StreamNumber):
-        return MediaInfoList_Count_Get (self.Handle, FilePos, StreamKind, StreamNumber=-1)
+        return self.MediaInfoList_Count_Get (self.Handle, FilePos, StreamKind, StreamNumber=-1)
     def Count_Get_Files(self):
-        return MediaInfoList_Count_Get_Files (self.Handle)
-
+        return self.MediaInfoList_Count_Get_Files (self.Handle)
